diff --git a/books/bookvol10.4.pamphlet b/books/bookvol10.4.pamphlet
index 2e1056b..fb1fa99 100644
--- a/books/bookvol10.4.pamphlet
+++ b/books/bookvol10.4.pamphlet
@@ -3676,13 +3676,14 @@ difference(getDomains 'IndexedAggregate,getDomains 'Collection)
 
 --S 3 of 5
 credits()
+--R 
 --RAn alphabetical listing of contributors to AXIOM:
 --RCyril Alberga          Roy Adler              Christian Aistleitner
 --RRichard Anderson       George Andrews         S.J. Atkins
 --RHenry Baker            Stephen Balzac         Yurij Baransky
 --RDavid R. Barton        Gerald Baumgartner     Gilbert Baumslag
---RJay Belanger           David Bindel           Fred Blair
---RVladimir Bondarenko    Mark Botch
+--RMichael Becker         Jay Belanger           David Bindel
+--RFred Blair             Vladimir Bondarenko    Mark Botch
 --RAlexandre Bouyer       Peter A. Broadbery     Martin Brock
 --RManuel Bronstein       Stephen Buchwald       Florian Bundschuh
 --RLuanne Burns           William Burge
@@ -5113,6 +5114,193 @@ BasicOperatorFunctions1(A:SetCategory): Exports == Implementation where
 
 @
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\section{package BEZIER Bezier}
+<<Bezier.input>>=
+)set break resume
+)sys rm -f Bezier.output
+)spool Bezier.output
+)set message test on
+)set message auto off
+)clear all
+--S 1
+n:=linearBezier([2.0,2.0],[4.0,4.0])
+--R
+--I   (1)  theMap(BEZIER;linearBezier;2LM;1!0,707)
+--R                                                  Type: (Float -> List Float)
+--E 1
+
+--S 2
+[n(t/10.0) for t in 0..10 by 1]
+--R
+--R   (2)
+--R   [[2.0,2.0], [2.2,2.2], [2.4,2.4], [2.6,2.6], [2.8,2.8], [3.0,3.0],
+--R    [3.2,3.2], [3.4,3.4], [3.6,3.6], [3.8,3.8], [4.0,4.0]]
+--R                                                        Type: List List Float
+--E 2
+
+--S 3
+n:=quadraticBezier([2.0,2.0],[4.0,4.0],[6.0,2.0])
+--R
+--I   (3)  theMap(BEZIER;quadraticBezier;3LM;2!0,291)
+--R                                                  Type: (Float -> List Float)
+--E 3
+
+--S 4
+[n(t/10.0) for t in 0..10 by 1]
+--R
+--R   (4)
+--R   [[2.0,2.0], [2.4,2.36], [2.8,2.64], [3.2,2.84], [3.6,2.96], [4.0,3.0],
+--R    [4.4,2.96], [4.8,2.84], [5.2,2.64], [5.6,2.36], [6.0,2.0]]
+--R                                                        Type: List List Float
+--E 4
+
+--S 5
+n:=cubicBezier([2.0,2.0],[2.0,4.0],[6.0,4.0],[6.0,2.0])
+--R
+--I   (5)  theMap(BEZIER;cubicBezier;4LM;3!0,915)
+--R                                                  Type: (Float -> List Float)
+--E 5
+
+--S 6
+[n(t/10.0) for t in 0..10 by 1]
+--R
+--R   (6)
+--R   [[2.0,2.0], [2.112,2.54], [2.416,2.96], [2.864,3.26], [3.408,3.44],
+--R    [4.0,3.5], [4.592,3.44], [5.136,3.26], [5.584,2.96], [5.888,2.54],
+--R    [6.0,2.0]]
+--R                                                        Type: List List Float
+--E 6
+
+@
+<<Bezier.help>>=
+====================================================================
+Bezier Curve examples
+====================================================================
+
+A linear Bezier curve is a simple interpolation between the 
+starting point and the ending point based on a parameter t.
+
+Given a start point a=[x1,y1] and an endpoint b=[x2,y2]
+f(t) == [(1-t)*x1 + t*x2, (1-t)*y1 + t*y2]
+
+n:=linearBezier([2.0,2.0],[4.0,4.0])
+   theMap(BEZIER;linearBezier;2LM;1!0,707)
+
+[n(t/10.0) for t in 0..10 by 1]
+   [[2.0,2.0], [2.2,2.2], [2.4,2.4], [2.6,2.6], [2.8,2.8], [3.0,3.0],
+    [3.2,3.2], [3.4,3.4], [3.6,3.6], [3.8,3.8], [4.0,4.0]]
+
+
+A quadratic Bezier curve is a simple interpolation between the 
+starting point, a middle point, and the ending point based on 
+a parameter t.
+
+Given a start point a=[x1,y1], a middle point b=[x2,y2], 
+and an endpoint c=[x3,y3]
+
+f(t) == [(1-t)^2 x1 + 2t(1-t) x2 + t^2 x3,
+         (1-t)^2 y1 + 2t(1-t) y2 + t^2 y3]
+
+n:=quadraticBezier([2.0,2.0],[4.0,4.0],[6.0,2.0])
+   theMap(BEZIER;quadraticBezier;3LM;2!0,291)
+
+[n(t/10.0) for t in 0..10 by 1]
+   [[2.0,2.0], [2.4,2.36], [2.8,2.64], [3.2,2.84], [3.6,2.96], [4.0,3.0],
+    [4.4,2.96], [4.8,2.84], [5.2,2.64], [5.6,2.36], [6.0,2.0]]
+
+A cubic Bezier curve is a simple interpolation between the 
+starting point, a left-middle point,, a right-middle point,
+and the ending point based on a parameter t.
+
+Given a start point a=[x1,y1], the left-middle point b=[x2,y2],
+the right-middle point c=[x3,y3] and an endpoint d=[x4,y4]
+
+f(t) == [(1-t)^3 x1 + 3t(1-t)^2 x2 + 3t^2 (1-t) x3 + t^3 x4,
+         (1-t)^3 y1 + 3t(1-t)^2 y2 + 3t^2 (1-t) y3 + t^3 y4]
+
+n:=cubicBezier([2.0,2.0],[2.0,4.0],[6.0,4.0],[6.0,2.0])
+   theMap(BEZIER;cubicBezier;4LM;3!0,915)
+
+[n(t/10.0) for t in 0..10 by 1]
+   [[2.0,2.0], [2.112,2.54], [2.416,2.96], [2.864,3.26], [3.408,3.44],
+    [4.0,3.5], [4.592,3.44], [5.136,3.26], [5.584,2.96], [5.888,2.54],
+    [6.0,2.0]]
+
+See Also:
+o )show Bezier
+
+@
+\pagehead{Bezier}{BEZIER}
+\pagepic{ps/v104bezier.ps}{BEZIER}{1.00}
+
+{\bf Exports:}\\
+\begin{tabular}{llll}
+\cross{BEZIER}{bezoutDiscriminant} &
+\cross{BEZIER}{bezoutMatrix} &
+\cross{BEZIER}{bezoutResultant} &
+\cross{BEZIER}{sylvesterMatrix} 
+\end{tabular}
+
+<<package BEZIER Bezier>>=
+)abbrev package BEZIER Bezier
+++ Author: Timothy Daly
+++ Date Created: 14 April 2009
+++ Description: Provide linear, quadratic, and cubic spline bezier curves
+Bezier(R:Ring): with
+   linearBezier: (x:List R,y:List R) -> Mapping(List R,R)
+   ++ A linear Bezier curve is a simple interpolation between the 
+   ++ starting point and the ending point based on a parameter t.
+   ++ Given a start point a=[x1,y1] and an endpoint b=[x2,y2]
+   ++ f(t) == [(1-t)*x1 + t*x2, (1-t)*y1 + t*y2]
+   ++
+   ++X n:=linearBezier([2.0,2.0],[4.0,4.0])
+   ++X [n(t/10.0) for t in 0..10 by 1]
+   quadraticBezier: (x:List R,y:List R,z:List R) -> Mapping(List R,R)
+   ++ A quadratic Bezier curve is a simple interpolation between the 
+   ++ starting point, a middle point, and the ending point based on 
+   ++ a parameter t.
+   ++ Given a start point a=[x1,y1], a middle point b=[x2,y2], 
+   ++ and an endpoint c=[x3,y3]
+   ++ f(t) == [(1-t)^2 x1 + 2t(1-t) x2 + t^2 x3,
+   ++          (1-t)^2 y1 + 2t(1-t) y2 + t^2 y3]
+   ++
+   ++X n:=quadraticBezier([2.0,2.0],[4.0,4.0],[6.0,2.0])
+   ++X [n(t/10.0) for t in 0..10 by 1]
+   cubicBezier: (w:List R,x:List R,y:List R,z:List R) -> Mapping(List R,R)
+   ++ A cubic Bezier curve is a simple interpolation between the 
+   ++ starting point, a left-middle point,, a right-middle point,
+   ++ and the ending point based on a parameter t.
+   ++ Given a start point a=[x1,y1], the left-middle point b=[x2,y2],
+   ++ the right-middle point c=[x3,y3] and an endpoint d=[x4,y4]
+   ++ f(t) == [(1-t)^3 x1 + 3t(1-t)^2 x2 + 3t^2 (1-t) x3 + t^3 x4,
+   ++          (1-t)^3 y1 + 3t(1-t)^2 y2 + 3t^2 (1-t) y3 + t^3 y4]
+   ++
+   ++X n:=cubicBezier([2.0,2.0],[2.0,4.0],[6.0,4.0],[6.0,2.0])
+   ++X [n(t/10.0) for t in 0..10 by 1]
+ == add
+   linearBezier(a,b) == 
+    [(1-#1)*(a.1) + #1*(b.1), (1-#1)*(a.2) + #1*(b.2)]
+
+   quadraticBezier(a,b,c) == 
+    [(1-#1)**2*(a.1) + 2*#1*(1-#1)*(b.1) + (#1)**2*(c.1),
+     (1-#1)**2*(a.2) + 2*#1*(1-#1)*(b.2) + (#1)**2*(c.2)]
+
+   cubicBezier(a,b,c,d) == 
+    [(1-#1)**3*(a.1) + 3*(#1)*(1-#1)**2*(b.1) 
+        + 3*(#1)**2*(1-#1)*(c.1) + (#1)**3*(d.1),
+     (1-#1)**3*(a.2) + 3*(#1)*(1-#1)**2*(b.2)
+        + 3*(#1)**2*(1-#1)*(c.2) + (#1)**3*(d.2)]
+     
+@
+<<BEZIER.dotabb>>=
+"BEZIER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=BEZIER"]
+"LMODULE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=LMODULE"]
+"SGROUP" [color="#4488FF",href="bookvol10.2.pdf#nameddest=SGROUP"]
+"BEZIER" -> "LMODULE"
+"BEZIER" -> "SGROUP"
+
+@
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \section{package BEZOUT BezoutMatrix}
 \pagehead{BezoutMatrix}{BEZOUT}
 \pagepic{ps/v104bezoutmatrix.ps}{BEZOUT}{1.00}
diff --git a/books/ps/v104bezier.ps b/books/ps/v104bezier.ps
new file mode 100644
index 0000000..9d3ce7a
--- /dev/null
+++ b/books/ps/v104bezier.ps
@@ -0,0 +1,326 @@
+%!PS-Adobe-2.0
+%%Creator: Graphviz version 2.16.1 (Mon Jul  7 18:20:33 UTC 2008)
+%%For: (root) root
+%%Title: pic
+%%Pages: (atend)
+%%BoundingBox: (atend)
+%%EndComments
+save
+%%BeginProlog
+/DotDict 200 dict def
+DotDict begin
+
+/setupLatin1 {
+mark
+/EncodingVector 256 array def
+ EncodingVector 0
+
+ISOLatin1Encoding 0 255 getinterval putinterval
+EncodingVector 45 /hyphen put
+
+% Set up ISO Latin 1 character encoding
+/starnetISO {
+        dup dup findfont dup length dict begin
+        { 1 index /FID ne { def }{ pop pop } ifelse
+        } forall
+        /Encoding EncodingVector def
+        currentdict end definefont
+} def
+/Times-Roman starnetISO def
+/Times-Italic starnetISO def
+/Times-Bold starnetISO def
+/Times-BoldItalic starnetISO def
+/Helvetica starnetISO def
+/Helvetica-Oblique starnetISO def
+/Helvetica-Bold starnetISO def
+/Helvetica-BoldOblique starnetISO def
+/Courier starnetISO def
+/Courier-Oblique starnetISO def
+/Courier-Bold starnetISO def
+/Courier-BoldOblique starnetISO def
+cleartomark
+} bind def
+
+%%BeginResource: procset graphviz 0 0
+/coord-font-family /Times-Roman def
+/default-font-family /Times-Roman def
+/coordfont coord-font-family findfont 8 scalefont def
+
+/InvScaleFactor 1.0 def
+/set_scale {
+       dup 1 exch div /InvScaleFactor exch def
+       scale
+} bind def
+
+% styles
+/solid { [] 0 setdash } bind def
+/dashed { [9 InvScaleFactor mul dup ] 0 setdash } bind def
+/dotted { [1 InvScaleFactor mul 6 InvScaleFactor mul] 0 setdash } bind def
+/invis {/fill {newpath} def /stroke {newpath} def /show {pop newpath} def} bind def
+/bold { 2 setlinewidth } bind def
+/filled { } bind def
+/unfilled { } bind def
+/rounded { } bind def
+/diagonals { } bind def
+
+% hooks for setting color 
+/nodecolor { sethsbcolor } bind def
+/edgecolor { sethsbcolor } bind def
+/graphcolor { sethsbcolor } bind def
+/nopcolor {pop pop pop} bind def
+
+/beginpage {	% i j npages
+	/npages exch def
+	/j exch def
+	/i exch def
+	/str 10 string def
+	npages 1 gt {
+		gsave
+			coordfont setfont
+			0 0 moveto
+			(\() show i str cvs show (,) show j str cvs show (\)) show
+		grestore
+	} if
+} bind def
+
+/set_font {
+	findfont exch
+	scalefont setfont
+} def
+
+% draw text fitted to its expected width
+/alignedtext {			% width text
+	/text exch def
+	/width exch def
+	gsave
+		width 0 gt {
+			[] 0 setdash
+			text stringwidth pop width exch sub text length div 0 text ashow
+		} if
+	grestore
+} def
+
+/boxprim {				% xcorner ycorner xsize ysize
+		4 2 roll
+		moveto
+		2 copy
+		exch 0 rlineto
+		0 exch rlineto
+		pop neg 0 rlineto
+		closepath
+} bind def
+
+/ellipse_path {
+	/ry exch def
+	/rx exch def
+	/y exch def
+	/x exch def
+	matrix currentmatrix
+	newpath
+	x y translate
+	rx ry scale
+	0 0 1 0 360 arc
+	setmatrix
+} bind def
+
+/endpage { showpage } bind def
+/showpage { } def
+
+/layercolorseq
+	[	% layer color sequence - darkest to lightest
+		[0 0 0]
+		[.2 .8 .8]
+		[.4 .8 .8]
+		[.6 .8 .8]
+		[.8 .8 .8]
+	]
+def
+
+/layerlen layercolorseq length def
+
+/setlayer {/maxlayer exch def /curlayer exch def
+	layercolorseq curlayer 1 sub layerlen mod get
+	aload pop sethsbcolor
+	/nodecolor {nopcolor} def
+	/edgecolor {nopcolor} def
+	/graphcolor {nopcolor} def
+} bind def
+
+/onlayer { curlayer ne {invis} if } def
+
+/onlayers {
+	/myupper exch def
+	/mylower exch def
+	curlayer mylower lt
+	curlayer myupper gt
+	or
+	{invis} if
+} def
+
+/curlayer 0 def
+
+%%EndResource
+%%EndProlog
+%%BeginSetup
+14 default-font-family set_font
+1 setmiterlimit
+% /arrowlength 10 def
+% /arrowwidth 5 def
+
+% make sure pdfmark is harmless for PS-interpreters other than Distiller
+/pdfmark where {pop} {userdict /pdfmark /cleartomark load put} ifelse
+% make '<<' and '>>' safe on PS Level 1 devices
+/languagelevel where {pop languagelevel}{1} ifelse
+2 lt {
+    userdict (<<) cvn ([) cvn load put
+    userdict (>>) cvn ([) cvn load put
+} if
+
+%%EndSetup
+setupLatin1
+%%Page: 1 1
+%%PageBoundingBox: 36 36 218 152
+%%PageOrientation: Portrait
+0 0 1 beginpage
+gsave
+36 36 182 116 boxprim clip newpath
+1 1 set_scale 0 rotate 40 40 translate
+0.167 0.600 1.000 graphcolor
+newpath -4 -4 moveto
+-4 716 lineto
+536 716 lineto
+536 -4 lineto
+closepath fill
+1 setlinewidth
+0.167 0.600 1.000 graphcolor
+newpath -4 -4 moveto
+-4 716 lineto
+536 716 lineto
+536 -4 lineto
+closepath stroke
+% BEZIER
+gsave
+[ /Rect [ 58 72 122 108 ]
+  /Border [ 0 0 0 ]
+  /Action << /Subtype /URI /URI (bookvol10.4.pdf#nameddest=BEZIER) >>
+  /Subtype /Link
+/ANN pdfmark
+0.939 0.733 1.000 nodecolor
+newpath 122 108 moveto
+58 108 lineto
+58 72 lineto
+122 72 lineto
+closepath fill
+1 setlinewidth
+filled
+0.939 0.733 1.000 nodecolor
+newpath 122 108 moveto
+58 108 lineto
+58 72 lineto
+122 72 lineto
+closepath stroke
+0.000 0.000 0.000 nodecolor
+14.00 /Times-Roman set_font
+65.5 85.9 moveto 49 (BEZIER) alignedtext
+grestore
+% LMODULE
+gsave
+[ /Rect [ 0 0 84 36 ]
+  /Border [ 0 0 0 ]
+  /Action << /Subtype /URI /URI (bookvol10.2.pdf#nameddest=LMODULE) >>
+  /Subtype /Link
+/ANN pdfmark
+0.606 0.733 1.000 nodecolor
+newpath 84 36 moveto
+2.63123e-14 36 lineto
+5.2458e-15 1.06581e-14 lineto
+84 0 lineto
+closepath fill
+1 setlinewidth
+filled
+0.606 0.733 1.000 nodecolor
+newpath 84 36 moveto
+2.63123e-14 36 lineto
+5.2458e-15 1.06581e-14 lineto
+84 0 lineto
+closepath stroke
+0.000 0.000 0.000 nodecolor
+14.00 /Times-Roman set_font
+7.5 13.9 moveto 69 (LMODULE) alignedtext
+grestore
+% BEZIER->LMODULE
+gsave
+1 setlinewidth
+0.000 0.000 0.000 edgecolor
+newpath 78 72 moveto
+73 64 66 54 60 44 curveto
+stroke
+0.000 0.000 0.000 edgecolor
+newpath 62.8 41.9 moveto
+54 36 lineto
+57.2 46.1 lineto
+closepath fill
+1 setlinewidth
+solid
+0.000 0.000 0.000 edgecolor
+newpath 62.8 41.9 moveto
+54 36 lineto
+57.2 46.1 lineto
+closepath stroke
+grestore
+% SGROUP
+gsave
+[ /Rect [ 102 0 174 36 ]
+  /Border [ 0 0 0 ]
+  /Action << /Subtype /URI /URI (bookvol10.2.pdf#nameddest=SGROUP) >>
+  /Subtype /Link
+/ANN pdfmark
+0.606 0.733 1.000 nodecolor
+newpath 174 36 moveto
+102 36 lineto
+102 1.06581e-14 lineto
+174 0 lineto
+closepath fill
+1 setlinewidth
+filled
+0.606 0.733 1.000 nodecolor
+newpath 174 36 moveto
+102 36 lineto
+102 1.06581e-14 lineto
+174 0 lineto
+closepath stroke
+0.000 0.000 0.000 nodecolor
+14.00 /Times-Roman set_font
+110 13.9 moveto 56 (SGROUP) alignedtext
+grestore
+% BEZIER->SGROUP
+gsave
+1 setlinewidth
+0.000 0.000 0.000 edgecolor
+newpath 102 72 moveto
+107 64 114 54 120 44 curveto
+stroke
+0.000 0.000 0.000 edgecolor
+newpath 122.8 46.1 moveto
+126 36 lineto
+117.2 41.9 lineto
+closepath fill
+1 setlinewidth
+solid
+0.000 0.000 0.000 edgecolor
+newpath 122.8 46.1 moveto
+126 36 lineto
+117.2 41.9 lineto
+closepath stroke
+grestore
+endpage
+showpage
+grestore
+%%PageTrailer
+%%EndPage: 1
+%%Trailer
+%%Pages: 1
+%%BoundingBox: 36 36 218 152
+end
+restore
+%%EOF
diff --git a/changelog b/changelog
index af22f17..fd00320 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,9 @@
+20090414 tpd src/axiom-website/patches.html 20090414.06.tpd.patch
+20090414 tpd src/input/unittest3.input add Bezier package
+20090414 tpd src/input/unittest2.input add Bezier package
+20090414 tpd src/algebra/exposed.lsp add Bezier package
+20090414 tpd src/algebra/Makefile add Bezier package
+20090414 tpd books/bookvol10.4 add Bezier package
 20090414 tpd src/axiom-website/patches.html 20090414.05.tpd.patch
 20090414 tpd Makefile report regression failures
 20090414 tpd src/axiom-website/patches.html 20090414.04.tpd.patch
diff --git a/src/algebra/Makefile.pamphlet b/src/algebra/Makefile.pamphlet
index 4da2584..f454c55 100644
--- a/src/algebra/Makefile.pamphlet
+++ b/src/algebra/Makefile.pamphlet
@@ -790,8 +790,8 @@ OASGP PDRING
 <<layer2>>=
 
 LAYER2=\
-  ${OUT}/API.o      ${OUT}/ASP29.o    \
-  ${OUT}/ATRIG.o    ${OUT}/ATRIG-.o   ${OUT}/BMODULE.o  ${OUT}/CACHSET.o  \
+  ${OUT}/API.o      ${OUT}/ASP29.o    ${OUT}/ATRIG.o    ${OUT}/ATRIG-.o   \
+  ${OUT}/BEZIER.o   ${OUT}/BMODULE.o  ${OUT}/CACHSET.o  \
   ${OUT}/CHARNZ.o   ${OUT}/CHARZ.o    ${OUT}/DVARCAT.o  ${OUT}/DVARCAT-.o \
   ${OUT}/ELEMFUN.o  ${OUT}/ELEMFUN-.o ${OUT}/ESTOOLS2.o ${OUT}/EVALAB.o   \
   ${OUT}/EVALAB-.o  ${OUT}/FAMONC.o   ${OUT}/FCOMP.o    ${OUT}/FEVALAB.o  \
@@ -869,6 +869,11 @@ LAYER2=\
 /*"ATRIG-" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
 "ATRIG-" -> "LMODULE/SGROUP"
 
+"BEZIER" [color="#FF4488",href="bookvol10.4.pdf#nameddest=BEZIER"]
+/*"BEZIER" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
+/*"BEZIER" -> {"SETCAT"; "BASTYPE"; "KOERCE" "SGROUP"; "MONOID"; "LMODULE"} */
+"BEZIER" -> "LMODULE/SGROUP"
+
 "BMODULE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=BMODULE"]
 /*"BMODULE" -> {"RING"; "RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"}*/
 /*"BMODULE" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
@@ -16435,7 +16440,8 @@ SPADHELP=\
  ${HELP}/ApplicationProgramInterface.help \
  ${HELP}/ArrayStack.help \
  ${HELP}/AssociationList.help        ${HELP}/BalancedBinaryTree.help \
- ${HELP}/BasicOperator.help          ${HELP}/BinaryExpansion.help \
+ ${HELP}/BasicOperator.help          ${HELP}/Bezier.help \
+ ${HELP}/BinaryExpansion.help \
  ${HELP}/BinarySearchTree.help       ${HELP}/CardinalNumber.help \
  ${HELP}/CartesianTensor.help        ${HELP}/Character.help \
  ${HELP}/CharacterClass.help         ${HELP}/CliffordAlgebra.help \
@@ -16525,7 +16531,8 @@ REGRESS=\
  ApplicationProgramInterface.regress \
  ArrayStack.regress \
  AssociationList.regress        BalancedBinaryTree.regress \
- BasicOperator.regress          BinaryExpansion.regress \
+ BasicOperator.regress          Bezier.regress \
+ BinaryExpansion.regress \
  BinarySearchTree.regress       CardinalNumber.regress \
  CartesianTensor.regress        Character.regress \
  CharacterClass.regress         CliffordAlgebra.regress \
@@ -16659,6 +16666,15 @@ ${HELP}/BasicOperator.help: ${BOOKS}/bookvol10.3.pamphlet
             >${INPUT}/BasicOperator.input
 	@echo "BasicOperator (BOP)" >>${HELPFILE}
 
+${HELP}/Bezier.help: ${BOOKS}/bookvol10.4.pamphlet
+	@echo 7004 create Bezier.help from ${BOOKS}/bookvol10.4.pamphlet
+	@${TANGLE} -R"Bezier.help" ${BOOKS}/bookvol10.4.pamphlet \
+            >${HELP}/Bezier.help
+	@cp ${HELP}/Bezier.help ${HELP}/BEZIER.help
+	@${TANGLE} -R"Bezier.input" ${BOOKS}/bookvol10.4.pamphlet \
+            >${INPUT}/Bezier.input
+	@echo "Bezier (BEZIER)" >>${HELPFILE}
+
 ${HELP}/BinaryExpansion.help: ${BOOKS}/bookvol10.3.pamphlet
 	@echo 7004 create BinaryExpansion.help from \
             ${BOOKS}/bookvol10.3.pamphlet
diff --git a/src/algebra/exposed.lsp.pamphlet b/src/algebra/exposed.lsp.pamphlet
index cc850fc..915404d 100644
--- a/src/algebra/exposed.lsp.pamphlet
+++ b/src/algebra/exposed.lsp.pamphlet
@@ -67,6 +67,7 @@
   (|BalancedBinaryTree| . BBTREE)
   (|BasicOperator| . BOP)
   (|BasicOperatorFunctions1| . BOP1)
+  (|Bezier| . BEZIER)
   (|BinaryExpansion| . BINARY)
   (|BinaryFile| . BINFILE)
   (|BinarySearchTree| . BSTREE)
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 0e3f6ef..ef0541a 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -1084,5 +1084,7 @@ readme add Michael Becker<br/>
 Makefile add Makefile.slackware chunk<br/>
 <a href="patches/20090414.05.tpd.patch">20090414.05.tpd.patch</a>
 Makefile report regression failures<br/>
+<a href="patches/20090414.06.tpd.patch">20090414.06.tpd.patch</a>
+bookvol10.4 add Bezier package<br/>
  </body>
 </html>
diff --git a/src/input/unittest2.input.pamphlet b/src/input/unittest2.input.pamphlet
index d83558f..09899d6 100644
--- a/src/input/unittest2.input.pamphlet
+++ b/src/input/unittest2.input.pamphlet
@@ -98,7 +98,7 @@ Unit test the user level commands
 --S 13 of 237
 )lisp (identity credits)
 --R 
---RValue = ("An alphabetical listing of contributors to AXIOM:" "Cyril Alberga          Roy Adler              Christian Aistleitner" "Richard Anderson       George Andrews         S.J. Atkins" "Henry Baker            Stephen Balzac         Yurij Baransky" "David R. Barton        Gerald Baumgartner     Gilbert Baumslag" "Jay Belanger           David Bindel           Fred Blair" "Vladimir Bondarenko    Mark Botch" "Alexandre Bouyer       Peter A. Broadbery     Martin Brock" "Manuel Bronstein       Stephen Buchwald       Florian Bundschuh" "Luanne Burns           William Burge" "Quentin Carpent        Robert Caviness        Bruce Char" "Ondrej Certik          Cheekai Chin           David V. Chudnovsky" "Gregory V. Chudnovsky  Josh Cohen             Christophe Conil" "Don Coppersmith        George Corliss         Robert Corless" "Gary Cornell           Meino Cramer           Claire Di Crescenzo" "David Cyganski" "Timothy Daly Sr.       Timothy Daly Jr.       James H. Davenport" "Didier Deshommes       Michael Dewar" "Jean Della Dora        Gabriel Dos Reis       Claire DiCrescendo" "Sam Dooley             Lionel Ducos           Martin Dunstan" "Brian Dupee            Dominique Duval" "Robert Edwards         Heow Eide-Goodman      Lars Erickson" "Richard Fateman        Bertfried Fauser       Stuart Feldman" "Brian Ford             Albrecht Fortenbacher  George Frances" "Constantine Frangos    Timothy Freeman        Korrinn Fu" "Marc Gaetano           Rudiger Gebauer        Kathy Gerber" "Patricia Gianni        Samantha Goldrich      Holger Gollan" "Teresa Gomez-Diaz      Laureano Gonzalez-Vega Stephen Gortler" "Johannes Grabmeier     Matt Grayson           Klaus Ebbe Grue" "James Griesmer         Vladimir Grinberg      Oswald Gschnitzer" "Jocelyn Guidry" "Steve Hague            Satoshi Hamaguchi      Mike Hansen" "Richard Harke          Vilya Harvey           Martin Hassner" "Arthur S. Hathaway     Dan Hatton             Waldek Hebisch" "Karl Hegbloom          Ralf Hemmecke          Henderson" "Antoine Hersen         Gernot Hueber" "Pietro Iglio" "Alejandro Jakubi       Richard Jenks" "Kai Kaminski           Grant Keady            Tony Kennedy" "Paul Kosinski          Klaus Kusche           Bernhard Kutzler" "Tim Lahey              Larry Lambe            Franz Lehner" "Frederic Lehobey       Michel Levaud          Howard Levy" "Liu Xiaojun            Rudiger Loos           Michael Lucks" "Richard Luczak" "Camm Maguire           Francois Maltey        Alasdair McAndrew" "Bob McElrath           Michael McGettrick     Ian Meikle" "David Mentre           Victor S. Miller       Gerard Milmeister" "Mohammed Mobarak       H. Michael Moeller     Michael Monagan" "Marc Moreno-Maza       Scott Morrison         Joel Moses" "Mark Murray" "William Naylor         C. Andrew Neff         John Nelder" "Godfrey Nolan          Arthur Norman          Jinzhong Niu" "Michael O'Connor       Summat Oemrawsingh     Kostas Oikonomou" "Humberto Ortiz-Zuazaga" "Julian A. Padget       Bill Page              Susan Pelzel" "Michel Petitot         Didier Pinchon         Ayal Pinkus" "Jose Alfredo Portes" "Claude Quitte" "Arthur C. Ralfs        Norman Ramsey          Anatoly Raportirenko" "Michael Richardson     Renaud Rioboo          Jean Rivlin" "Nicolas Robidoux       Simon Robinson         Raymond Rogers" "Michael Rothstein      Martin Rubey" "Philip Santas          Alfred Scheerhorn      William Schelter" "Gerhard Schneider      Martin Schoenert       Marshall Schor" "Frithjof Schulze       Fritz Schwarz          Nick Simicich" "William Sit            Elena Smirnova         Jonathan Steinbach" "Fabio Stumbo           Christine Sundaresan   Robert Sutor" "Moss E. Sweedler       Eugene Surowitz" "Max Tegmark            James Thatcher         Balbir Thomas" "Mike Thomas            Dylan Thurston         Barry Trager" "Themos T. Tsikas" "Gregory Vanuxem" "Bernhard Wall          Stephen Watt           Jaap Weel" "Juergen Weiss          M. Weller              Mark Wegman" "James Wen              Thorsten Werther       Michael Wester" "John M. Wiley          Berhard Will           Clifton J. Williamson" "Stephen Wilson         Shmuel Winograd        Robert Wisbauer" "Sandra Wityak          Waldemar Wiwianka      Knut Wolf" "Clifford Yapp          David Yun" "Vadim Zhytnikov        Richard Zippel         Evelyn Zoernack" "Bruno Zuercher         Dan Zwillinger")
+--RValue = ("An alphabetical listing of contributors to AXIOM:" "Cyril Alberga          Roy Adler              Christian Aistleitner" "Richard Anderson       George Andrews         S.J. Atkins" "Henry Baker            Stephen Balzac         Yurij Baransky" "David R. Barton        Gerald Baumgartner     Gilbert Baumslag" "Michael Becker         Jay Belanger           David Bindel" "Fred Blair             Vladimir Bondarenko    Mark Botch" "Alexandre Bouyer       Peter A. Broadbery     Martin Brock" "Manuel Bronstein       Stephen Buchwald       Florian Bundschuh" "Luanne Burns           William Burge" "Quentin Carpent        Robert Caviness        Bruce Char" "Ondrej Certik          Cheekai Chin           David V. Chudnovsky" "Gregory V. Chudnovsky  Josh Cohen             Christophe Conil" "Don Coppersmith        George Corliss         Robert Corless" "Gary Cornell           Meino Cramer           Claire Di Crescenzo" "David Cyganski" "Timothy Daly Sr.       Timothy Daly Jr.       James H. Davenport" "Didier Deshommes       Michael Dewar" "Jean Della Dora        Gabriel Dos Reis       Claire DiCrescendo" "Sam Dooley             Lionel Ducos           Martin Dunstan" "Brian Dupee            Dominique Duval" "Robert Edwards         Heow Eide-Goodman      Lars Erickson" "Richard Fateman        Bertfried Fauser       Stuart Feldman" "Brian Ford             Albrecht Fortenbacher  George Frances" "Constantine Frangos    Timothy Freeman        Korrinn Fu" "Marc Gaetano           Rudiger Gebauer        Kathy Gerber" "Patricia Gianni        Samantha Goldrich      Holger Gollan" "Teresa Gomez-Diaz      Laureano Gonzalez-Vega Stephen Gortler" "Johannes Grabmeier     Matt Grayson           Klaus Ebbe Grue" "James Griesmer         Vladimir Grinberg      Oswald Gschnitzer" "Jocelyn Guidry" "Steve Hague            Satoshi Hamaguchi      Mike Hansen" "Richard Harke          Vilya Harvey           Martin Hassner" "Arthur S. Hathaway     Dan Hatton             Waldek Hebisch" "Karl Hegbloom          Ralf Hemmecke          Henderson" "Antoine Hersen         Gernot Hueber" "Pietro Iglio" "Alejandro Jakubi       Richard Jenks" "Kai Kaminski           Grant Keady            Tony Kennedy" "Paul Kosinski          Klaus Kusche           Bernhard Kutzler" "Tim Lahey              Larry Lambe            Franz Lehner" "Frederic Lehobey       Michel Levaud          Howard Levy" "Liu Xiaojun            Rudiger Loos           Michael Lucks" "Richard Luczak" "Camm Maguire           Francois Maltey        Alasdair McAndrew" "Bob McElrath           Michael McGettrick     Ian Meikle" "David Mentre           Victor S. Miller       Gerard Milmeister" "Mohammed Mobarak       H. Michael Moeller     Michael Monagan" "Marc Moreno-Maza       Scott Morrison         Joel Moses" "Mark Murray" "William Naylor         C. Andrew Neff         John Nelder" "Godfrey Nolan          Arthur Norman          Jinzhong Niu" "Michael O'Connor       Summat Oemrawsingh     Kostas Oikonomou" "Humberto Ortiz-Zuazaga" "Julian A. Padget       Bill Page              Susan Pelzel" "Michel Petitot         Didier Pinchon         Ayal Pinkus" "Jose Alfredo Portes" "Claude Quitte" "Arthur C. Ralfs        Norman Ramsey          Anatoly Raportirenko" "Michael Richardson     Renaud Rioboo          Jean Rivlin" "Nicolas Robidoux       Simon Robinson         Raymond Rogers" "Michael Rothstein      Martin Rubey" "Philip Santas          Alfred Scheerhorn      William Schelter" "Gerhard Schneider      Martin Schoenert       Marshall Schor" "Frithjof Schulze       Fritz Schwarz          Nick Simicich" "William Sit            Elena Smirnova         Jonathan Steinbach" "Fabio Stumbo           Christine Sundaresan   Robert Sutor" "Moss E. Sweedler       Eugene Surowitz" "Max Tegmark            James Thatcher         Balbir Thomas" "Mike Thomas            Dylan Thurston         Barry Trager" "Themos T. Tsikas" "Gregory Vanuxem" "Bernhard Wall          Stephen Watt           Jaap Weel" "Juergen Weiss          M. Weller              Mark Wegman" "James Wen              Thorsten Werther       Michael Wester" "John M. Wiley          Berhard Will           Clifton J. Williamson" "Stephen Wilson         Shmuel Winograd        Robert Wisbauer" "Sandra Wityak          Waldemar Wiwianka      Knut Wolf" "Clifford Yapp          David Yun" "Vadim Zhytnikov        Richard Zippel         Evelyn Zoernack" "Bruno Zuercher         Dan Zwillinger")
 --E 13
 
 --S 14 of 237
@@ -969,7 +969,7 @@ Unit test the user level commands
 --S 155 of 237
 )lisp (identity |$globalExposureGroupAlist|)
 --R 
---RValue = ((|basic| (|AlgebraicManipulations| . ALGMANIP) (|AlgebraicNumber| . AN) (|AlgFactor| . ALGFACT) (|AlgebraicMultFact| . ALGMFACT) (|AlgebraPackage| . ALGPKG) (|AlgebraGivenByStructuralConstants| . ALGSC) (|Any| . ANY) (|AnyFunctions1| . ANY1) (|ApplicationProgramInterface| . API) (|ArrayStack| . ASTACK) (|AssociatedJordanAlgebra| . JORDAN) (|AssociatedLieAlgebra| . LIE) (|AttachPredicates| . PMPRED) (|AxiomServer| . AXSERV) (|BalancedBinaryTree| . BBTREE) (|BasicOperator| . BOP) (|BasicOperatorFunctions1| . BOP1) (|BinaryExpansion| . BINARY) (|BinaryFile| . BINFILE) (|BinarySearchTree| . BSTREE) (|BinaryTournament| . BTOURN) (|BinaryTree| . BTREE) (|Bits| . BITS) (|Boolean| . BOOLEAN) (|CardinalNumber| . CARD) (|CartesianTensor| . CARTEN) (|CartesianTensorFunctions2| . CARTEN2) (|Character| . CHAR) (|CharacterClass| . CCLASS) (|CharacteristicPolynomialPackage| . CHARPOL) (|CliffordAlgebra| . CLIF) (|Color| . COLOR) (|CommonDenominator| . CDEN) (|Commutator| . COMM) (|Complex| . COMPLEX) (|ComplexFactorization| . COMPFACT) (|ComplexFunctions2| . COMPLEX2) (|ComplexRootPackage| . CMPLXRT) (|ComplexTrigonometricManipulations| . CTRIGMNP) (|ContinuedFraction| . CONTFRAC) (|CoordinateSystems| . COORDSYS) (|CRApackage| . CRAPACK) (|CycleIndicators| . CYCLES) (|Database| . DBASE) (|DataList| . DLIST) (|DecimalExpansion| . DECIMAL) (|DenavitHartenbergMatrix| . DHMATRIX) (|Dequeue| . DEQUEUE) (|DiophantineSolutionPackage| . DIOSP) (|DirectProductFunctions2| . DIRPROD2) (|DisplayPackage| . DISPLAY) (|DistinctDegreeFactorize| . DDFACT) (|DoubleFloat| . DFLOAT) (|DoubleFloatSpecialFunctions| . DFSFUN) (|DrawComplex| . DRAWCX) (|DrawNumericHack| . DRAWHACK) (|DrawOption| . DROPT) (|EigenPackage| . EP) (|ElementaryFunctionDefiniteIntegration| . DEFINTEF) (|ElementaryFunctionLODESolver| . LODEEF) (|ElementaryFunctionODESolver| . ODEEF) (|ElementaryFunctionSign| . SIGNEF) (|ElementaryFunctionStructurePackage| . EFSTRUC) (|Equation| . EQ) (|EquationFunctions2| . EQ2) (|ErrorFunctions| . ERROR) (|EuclideanGroebnerBasisPackage| . GBEUCLID) (|Exit| . EXIT) (|Expression| . EXPR) (|ExpressionFunctions2| . EXPR2) (|ExpressionSolve| . EXPRSOL) (|ExpressionSpaceFunctions2| . ES2) (|ExpressionSpaceODESolver| . EXPRODE) (|ExpressionToOpenMath| . OMEXPR) (|ExpressionToUnivariatePowerSeries| . EXPR2UPS) (|Factored| . FR) (|FactoredFunctions2| . FR2) (|File| . FILE) (|FileName| . FNAME) (|FiniteAbelianMonoidRingFunctions2| . FAMR2) (|FiniteDivisorFunctions2| . FDIV2) (|FiniteField| . FF) (|FiniteFieldCyclicGroup| . FFCG) (|FiniteFieldPolynomialPackage2| . FFPOLY2) (|FiniteFieldNormalBasis| . FFNB) (|FiniteFieldHomomorphisms| . FFHOM) (|FiniteLinearAggregateFunctions2| . FLAGG2) (|FiniteLinearAggregateSort| . FLASORT) (|FiniteSetAggregateFunctions2| . FSAGG2) (|FlexibleArray| . FARRAY) (|Float| . FLOAT) (|FloatingRealPackage| . FLOATRP) (|FloatingComplexPackage| . FLOATCP) (|FourierSeries| . FSERIES) (|Fraction| . FRAC) (|FractionalIdealFunctions2| . FRIDEAL2) (|FractionFreeFastGaussian| . FFFG) (|FractionFreeFastGaussianFractions| . FFFGF) (|FractionFunctions2| . FRAC2) (|FreeNilpotentLie| . FNLA) (|FullPartialFractionExpansion| . FPARFRAC) (|FunctionFieldCategoryFunctions2| . FFCAT2) (|FunctionSpaceAssertions| . PMASSFS) (|FunctionSpaceAttachPredicates| . PMPREDFS) (|FunctionSpaceComplexIntegration| . FSCINT) (|FunctionSpaceFunctions2| . FS2) (|FunctionSpaceIntegration| . FSINT) (|FunctionSpacePrimitiveElement| . FSPRMELT) (|FunctionSpaceSum| . SUMFS) (|GaussianFactorizationPackage| . GAUSSFAC) (|GeneralUnivariatePowerSeries| . GSERIES) (|GenerateUnivariatePowerSeries| . GENUPS) (|GraphicsDefaults| . GRDEF) (|GroebnerPackage| . GB) (|GroebnerFactorizationPackage| . GBF) (|Guess| . GUESS) (|GuessAlgebraicNumber| . GUESSAN) (|GuessFinite| . GUESSF) (|GuessFiniteFunctions| . GUESSF1) (|GuessInteger| . GUESSINT) (|GuessOption| . GOPT) (|GuessOptionFunctions0| . GOPT0) (|GuessPolynomial| . GUESSP) (|GuessUnivariatePolynomial| . GUESSUP) (|HallBasis| . HB) (|Heap| . HEAP) (|HexadecimalExpansion| . HEXADEC) (|IndexCard| . ICARD) (|IdealDecompositionPackage| . IDECOMP) (|InfiniteProductCharacteristicZero| . INFPROD0) (|InfiniteProductFiniteField| . INPRODFF) (|InfiniteProductPrimeField| . INPRODPF) (|InfiniteTuple| . ITUPLE) (|InfiniteTupleFunctions2| . ITFUN2) (|InfiniteTupleFunctions3| . ITFUN3) (|Infinity| . INFINITY) (|Integer| . INT) (|IntegerCombinatoricFunctions| . COMBINAT) (|IntegerLinearDependence| . ZLINDEP) (|IntegerNumberTheoryFunctions| . INTHEORY) (|IntegerPrimesPackage| . PRIMES) (|IntegerRetractions| . INTRET) (|IntegerRoots| . IROOT) (|IntegrationResultFunctions2| . IR2) (|IntegrationResultRFToFunction| . IRRF2F) (|IntegrationResultToFunction| . IR2F) (|Interval| . INTRVL) (|InventorDataSink| . IVDATA) (|InventorViewPort| . IVVIEW) (|InventorRenderPackage| . IVREND) (|InverseLaplaceTransform| . INVLAPLA) (|IrrRepSymNatPackage| . IRSN) (|KernelFunctions2| . KERNEL2) (|KeyedAccessFile| . KAFILE) (|LaplaceTransform| . LAPLACE) (|LazardMorenoSolvingPackage| . LAZM3PK) (|Library| . LIB) (|LieSquareMatrix| . LSQM) (|LinearOrdinaryDifferentialOperator| . LODO) (|LinearSystemMatrixPackage| . LSMP) (|LinearSystemMatrixPackage1| . LSMP1) (|LinearSystemPolynomialPackage| . LSPP) (|List| . LIST) (|ListFunctions2| . LIST2) (|ListFunctions3| . LIST3) (|ListToMap| . LIST2MAP) (|MakeFloatCompiledFunction| . MKFLCFN) (|MakeFunction| . MKFUNC) (|MakeRecord| . MKRECORD) (|MappingPackage1| . MAPPKG1) (|MappingPackage2| . MAPPKG2) (|MappingPackage3| . MAPPKG3) (|MappingPackage4| . MAPPKG4) (|MathMLFormat| . MMLFORM) (|Matrix| . MATRIX) (|MatrixCategoryFunctions2| . MATCAT2) (|MatrixCommonDenominator| . MCDEN) (|MatrixLinearAlgebraFunctions| . MATLIN) (|MergeThing| . MTHING) (|ModularDistinctDegreeFactorizer| . MDDFACT) (|ModuleOperator| . MODOP) (|MonoidRingFunctions2| . MRF2) (|MoreSystemCommands| . MSYSCMD) (|MPolyCatFunctions2| . MPC2) (|MPolyCatRationalFunctionFactorizer| . MPRFF) (|Multiset| . MSET) (|MultivariateFactorize| . MULTFACT) (|MultivariatePolynomial| . MPOLY) (|MultFiniteFactorize| . MFINFACT) (|MyUnivariatePolynomial| . MYUP) (|MyExpression| . MYEXPR) (|NoneFunctions1| . NONE1) (|NonNegativeInteger| . NNI) (|NottinghamGroup| . NOTTING) (|NormalizationPackage| . NORMPK) (|NormInMonogenicAlgebra| . NORMMA) (|NumberTheoreticPolynomialFunctions| . NTPOLFN) (|Numeric| . NUMERIC) (|NumericalOrdinaryDifferentialEquations| . NUMODE) (|NumericalQuadrature| . NUMQUAD) (|NumericComplexEigenPackage| . NCEP) (|NumericRealEigenPackage| . NREP) (|NumericContinuedFraction| . NCNTFRAC) (|Octonion| . OCT) (|OctonionCategoryFunctions2| . OCTCT2) (|OneDimensionalArray| . ARRAY1) (|OneDimensionalArrayFunctions2| . ARRAY12) (|OnePointCompletion| . ONECOMP) (|OnePointCompletionFunctions2| . ONECOMP2) (|OpenMathConnection| . OMCONN) (|OpenMathDevice| . OMDEV) (|OpenMathEncoding| . OMENC) (|OpenMathError| . OMERR) (|OpenMathErrorKind| . OMERRK) (|OpenMathPackage| . OMPKG) (|OpenMathServerPackage| . OMSERVER) (|OperationsQuery| . OPQUERY) (|OrderedCompletion| . ORDCOMP) (|OrderedCompletionFunctions2| . ORDCOMP2) (|OrdinaryDifferentialRing| . ODR) (|OrdSetInts| . OSI) (|OrthogonalPolynomialFunctions| . ORTHPOL) (|OutputPackage| . OUT) (|PadeApproximantPackage| . PADEPAC) (|Palette| . PALETTE) (|PartialFraction| . PFR) (|PatternFunctions2| . PATTERN2) (|ParametricPlaneCurve| . PARPCURV) (|ParametricSpaceCurve| . PARSCURV) (|ParametricSurface| . PARSURF) (|ParametricPlaneCurveFunctions2| . PARPC2) (|ParametricSpaceCurveFunctions2| . PARSC2) (|ParametricSurfaceFunctions2| . PARSU2) (|PartitionsAndPermutations| . PARTPERM) (|PatternMatch| . PATMATCH) (|PatternMatchAssertions| . PMASS) (|PatternMatchResultFunctions2| . PATRES2) (|PendantTree| . PENDTREE) (|Permanent| . PERMAN) (|PermutationGroupExamples| . PGE) (|PermutationGroup| . PERMGRP) (|Permutation| . PERM) (|Pi| . HACKPI) (|PiCoercions| . PICOERCE) (|PointFunctions2| . PTFUNC2) (|PolyGroebner| . PGROEB) (|Polynomial| . POLY) (|PolynomialAN2Expression| . PAN2EXPR) (|PolynomialComposition| . PCOMP) (|PolynomialDecomposition| . PDECOMP) (|PolynomialFunctions2| . POLY2) (|PolynomialIdeals| . IDEAL) (|PolynomialToUnivariatePolynomial| . POLY2UP) (|PositiveInteger| . PI) (|PowerSeriesLimitPackage| . LIMITPS) (|PrimeField| . PF) (|PrimitiveArrayFunctions2| . PRIMARR2) (|PrintPackage| . PRINT) (|QuadraticForm| . QFORM) (|QuasiComponentPackage| . QCMPACK) (|Quaternion| . QUAT) (|QuaternionCategoryFunctions2| . QUATCT2) (|QueryEquation| . QEQUAT) (|Queue| . QUEUE) (|QuotientFieldCategoryFunctions2| . QFCAT2) (|RadicalEigenPackage| . REP) (|RadicalSolvePackage| . SOLVERAD) (|RadixExpansion| . RADIX) (|RadixUtilities| . RADUTIL) (|RandomNumberSource| . RANDSRC) (|RationalFunction| . RF) (|RationalFunctionDefiniteIntegration| . DEFINTRF) (|RationalFunctionFactor| . RFFACT) (|RationalFunctionFactorizer| . RFFACTOR) (|RationalFunctionIntegration| . INTRF) (|RationalFunctionLimitPackage| . LIMITRF) (|RationalFunctionSign| . SIGNRF) (|RationalFunctionSum| . SUMRF) (|RationalRetractions| . RATRET) (|RealClosure| . RECLOS) (|RealPolynomialUtilitiesPackage| . POLUTIL) (|RealZeroPackage| . REAL0) (|RealZeroPackageQ| . REAL0Q) (|RecurrenceOperator| . RECOP) (|RectangularMatrixCategoryFunctions2| . RMCAT2) (|RegularSetDecompositionPackage| . RSDCMPK) (|RegularTriangularSet| . REGSET) (|RegularTriangularSetGcdPackage| . RSETGCD) (|RepresentationPackage1| . REP1) (|RepresentationPackage2| . REP2) (|ResolveLatticeCompletion| . RESLATC) (|RewriteRule| . RULE) (|RightOpenIntervalRootCharacterization| . ROIRC) (|RomanNumeral| . ROMAN) (|Ruleset| . RULESET) (|ScriptFormulaFormat| . FORMULA) (|ScriptFormulaFormat1| . FORMULA1) (|Segment| . SEG) (|SegmentBinding| . SEGBIND) (|SegmentBindingFunctions2| . SEGBIND2) (|SegmentFunctions2| . SEG2) (|Set| . SET) (|SimpleAlgebraicExtensionAlgFactor| . SAEFACT) (|SimplifyAlgebraicNumberConvertPackage| . SIMPAN) (|SingleInteger| . SINT) (|SmithNormalForm| . SMITH) (|SparseUnivariatePolynomialExpressions| . SUPEXPR) (|SparseUnivariatePolynomialFunctions2| . SUP2) (|SpecialOutputPackage| . SPECOUT) (|SquareFreeRegularSetDecompositionPackage| . SRDCMPK) (|SquareFreeRegularTriangularSet| . SREGSET) (|SquareFreeRegularTriangularSetGcdPackage| . SFRGCD) (|SquareFreeQuasiComponentPackage| . SFQCMPK) (|Stack| . STACK) (|Stream| . STREAM) (|StreamFunctions1| . STREAM1) (|StreamFunctions2| . STREAM2) (|StreamFunctions3| . STREAM3) (|String| . STRING) (|SturmHabichtPackage| . SHP) (|Symbol| . SYMBOL) (|SymmetricGroupCombinatoricFunctions| . SGCF) (|SystemSolvePackage| . SYSSOLP) (|SAERationalFunctionAlgFactor| . SAERFFC) (|Tableau| . TABLEAU) (|TaylorSeries| . TS) (|TaylorSolve| . UTSSOL) (|TexFormat| . TEX) (|TexFormat1| . TEX1) (|TextFile| . TEXTFILE) (|ThreeDimensionalViewport| . VIEW3D) (|ThreeSpace| . SPACE3) (|Timer| . TIMER) (|TopLevelDrawFunctions| . DRAW) (|TopLevelDrawFunctionsForAlgebraicCurves| . DRAWCURV) (|TopLevelDrawFunctionsForCompiledFunctions| . DRAWCFUN) (|TopLevelDrawFunctionsForPoints| . DRAWPT) (|TopLevelThreeSpace| . TOPSP) (|TranscendentalManipulations| . TRMANIP) (|TransSolvePackage| . SOLVETRA) (|Tree| . TREE) (|TrigonometricManipulations| . TRIGMNIP) (|UnivariateLaurentSeriesFunctions2| . ULS2) (|UnivariateFormalPowerSeries| . UFPS) (|UnivariateFormalPowerSeriesFunctions| . UFPS1) (|UnivariatePolynomial| . UP) (|UnivariatePolynomialCategoryFunctions2| . UPOLYC2) (|UnivariatePolynomialCommonDenominator| . UPCDEN) (|UnivariatePolynomialFunctions2| . UP2) (|UnivariatePolynomialMultiplicationPackage| . UPMP) (|UnivariatePuiseuxSeriesFunctions2| . UPXS2) (|UnivariateTaylorSeriesFunctions2| . UTS2) (|UniversalSegment| . UNISEG) (|UniversalSegmentFunctions2| . UNISEG2) (|UserDefinedVariableOrdering| . UDVO) (|Vector| . VECTOR) (|VectorFunctions2| . VECTOR2) (|ViewDefaultsPackage| . VIEWDEF) (|Void| . VOID) (|WuWenTsunTriangularSet| . WUTSET)) (|naglink| (|Asp1| . ASP1) (|Asp4| . ASP4) (|Asp6| . ASP6) (|Asp7| . ASP7) (|Asp8| . ASP8) (|Asp9| . ASP9) (|Asp10| . ASP10) (|Asp12| . ASP12) (|Asp19| . ASP19) (|Asp20| . ASP20) (|Asp24| . ASP24) (|Asp27| . ASP27) (|Asp28| . ASP28) (|Asp29| . ASP29) (|Asp30| . ASP30) (|Asp31| . ASP31) (|Asp33| . ASP33) (|Asp34| . ASP34) (|Asp35| . ASP35) (|Asp41| . ASP41) (|Asp42| . ASP42) (|Asp49| . ASP49) (|Asp50| . ASP50) (|Asp55| . ASP55) (|Asp73| . ASP73) (|Asp74| . ASP74) (|Asp77| . ASP77) (|Asp78| . ASP78) (|Asp80| . ASP80) (|FortranCode| . FC) (|FortranCodePackage1| . FCPAK1) (|FortranExpression| . FEXPR) (|FortranMachineTypeCategory| . FMTC) (|FortranMatrixCategory| . FMC) (|FortranMatrixFunctionCategory| . FMFUN) (|FortranOutputStackPackage| . FOP) (|FortranPackage| . FORT) (|FortranProgramCategory| . FORTCAT) (|FortranProgram| . FORTRAN) (|FortranFunctionCategory| . FORTFN) (|FortranScalarType| . FST) (|FortranType| . FT) (|FortranTemplate| . FTEM) (|FortranVectorFunctionCategory| . FVFUN) (|FortranVectorCategory| . FVC) (|MachineComplex| . MCMPLX) (|MachineFloat| . MFLOAT) (|MachineInteger| . MINT) (|MultiVariableCalculusFunctions| . MCALCFN) (|NagDiscreteFourierTransformInterfacePackage| . NAGDIS) (|NagEigenInterfacePackage| . NAGEIG) (|NAGLinkSupportPackage| . NAGSP) (|NagOptimisationInterfacePackage| . NAGOPT) (|NagQuadratureInterfacePackage| . NAGQUA) (|NagResultChecks| . NAGRES) (|NagSpecialFunctionsInterfacePackage| . NAGSPE) (|NagPolynomialRootsPackage| . NAGC02) (|NagRootFindingPackage| . NAGC05) (|NagSeriesSummationPackage| . NAGC06) (|NagIntegrationPackage| . NAGD01) (|NagOrdinaryDifferentialEquationsPackage| . NAGD02) (|NagPartialDifferentialEquationsPackage| . NAGD03) (|NagInterpolationPackage| . NAGE01) (|NagFittingPackage| . NAGE02) (|NagOptimisationPackage| . NAGE04) (|NagMatrixOperationsPackage| . NAGF01) (|NagEigenPackage| . NAGF02) (|NagLinearEquationSolvingPackage| . NAGF04) (|NagLapack| . NAGF07) (|NagSpecialFunctionsPackage| . NAGS) (|PackedHermitianSequence| . PACKED) (|Result| . RESULT) (|SimpleFortranProgram| . SFORT) (|Switch| . SWITCH) (|SymbolTable| . SYMTAB) (|TemplateUtilities| . TEMUTL) (|TheSymbolTable| . SYMS) (|ThreeDimensionalMatrix| . M3D)) (|anna| (|AnnaNumericalIntegrationPackage| . INTPACK) (|AnnaNumericalOptimizationPackage| . OPTPACK) (|AnnaOrdinaryDifferentialEquationPackage| . ODEPACK) (|AnnaPartialDifferentialEquationPackage| . PDEPACK) (|AttributeButtons| . ATTRBUT) (|BasicFunctions| . BFUNCT) (|d01ajfAnnaType| . D01AJFA) (|d01akfAnnaType| . D01AKFA) (|d01alfAnnaType| . D01ALFA) (|d01amfAnnaType| . D01AMFA) (|d01anfAnnaType| . D01ANFA) (|d01apfAnnaType| . D01APFA) (|d01aqfAnnaType| . D01AQFA) (|d01asfAnnaType| . D01ASFA) (|d01fcfAnnaType| . D01FCFA) (|d01gbfAnnaType| . D01GBFA) (|d01AgentsPackage| . D01AGNT) (|d01TransformFunctionType| . D01TRNS) (|d01WeightsPackage| . D01WGTS) (|d02AgentsPackage| . D02AGNT) (|d02bbfAnnaType| . D02BBFA) (|d02bhfAnnaType| . D02BHFA) (|d02cjfAnnaType| . D02CJFA) (|d02ejfAnnaType| . D02EJFA) (|d03AgentsPackage| . D03AGNT) (|d03eefAnnaType| . D03EEFA) (|d03fafAnnaType| . D03FAFA) (|e04AgentsPackage| . E04AGNT) (|e04dgfAnnaType| . E04DGFA) (|e04fdfAnnaType| . E04FDFA) (|e04gcfAnnaType| . E04GCFA) (|e04jafAnnaType| . E04JAFA) (|e04mbfAnnaType| . E04MBFA) (|e04nafAnnaType| . E04NAFA) (|e04ucfAnnaType| . E04UCFA) (|ExpertSystemContinuityPackage| . ESCONT) (|ExpertSystemContinuityPackage1| . ESCONT1) (|ExpertSystemToolsPackage| . ESTOOLS) (|ExpertSystemToolsPackage1| . ESTOOLS1) (|ExpertSystemToolsPackage2| . ESTOOLS2) (|NumericalIntegrationCategory| . NUMINT) (|NumericalIntegrationProblem| . NIPROB) (|NumericalODEProblem| . ODEPROB) (|NumericalOptimizationCategory| . OPTCAT) (|NumericalOptimizationProblem| . OPTPROB) (|NumericalPDEProblem| . PDEPROB) (|ODEIntensityFunctionsTable| . ODEIFTBL) (|IntegrationFunctionsTable| . INTFTBL) (|OrdinaryDifferentialEquationsSolverCategory| . ODECAT) (|PartialDifferentialEquationsSolverCategory| . PDECAT) (|RoutinesTable| . ROUTINE)) (|categories| (|AbelianGroup| . ABELGRP) (|AbelianMonoid| . ABELMON) (|AbelianMonoidRing| . AMR) (|AbelianSemiGroup| . ABELSG) (|Aggregate| . AGG) (|Algebra| . ALGEBRA) (|AlgebraicallyClosedField| . ACF) (|AlgebraicallyClosedFunctionSpace| . ACFS) (|ArcHyperbolicFunctionCategory| . AHYP) (|ArcTrigonometricFunctionCategory| . ATRIG) (|AssociationListAggregate| . ALAGG) (|AttributeRegistry| . ATTREG) (|BagAggregate| . BGAGG) (|BasicType| . BASTYPE) (|BiModule| . BMODULE) (|BinaryRecursiveAggregate| . BRAGG) (|BinaryTreeCategory| . BTCAT) (|BitAggregate| . BTAGG) (|CachableSet| . CACHSET) (|CancellationAbelianMonoid| . CABMON) (|CharacteristicNonZero| . CHARNZ) (|CharacteristicZero| . CHARZ) (|CoercibleTo| . KOERCE) (|Collection| . CLAGG) (|CombinatorialFunctionCategory| . CFCAT) (|CombinatorialOpsCategory| . COMBOPC) (|CommutativeRing| . COMRING) (|ComplexCategory| . COMPCAT) (|ConvertibleTo| . KONVERT) (|DequeueAggregate| . DQAGG) (|Dictionary| . DIAGG) (|DictionaryOperations| . DIOPS) (|DifferentialExtension| . DIFEXT) (|DifferentialPolynomialCategory| . DPOLCAT) (|DifferentialRing| . DIFRING) (|DifferentialVariableCategory| . DVARCAT) (|DirectProductCategory| . DIRPCAT) (|DivisionRing| . DIVRING) (|DoublyLinkedAggregate| . DLAGG) (|ElementaryFunctionCategory| . ELEMFUN) (|Eltable| . ELTAB) (|EltableAggregate| . ELTAGG) (|EntireRing| . ENTIRER) (|EuclideanDomain| . EUCDOM) (|Evalable| . EVALAB) (|ExpressionSpace| . ES) (|ExtensibleLinearAggregate| . ELAGG) (|ExtensionField| . XF) (|Field| . FIELD) (|FieldOfPrimeCharacteristic| . FPC) (|Finite| . FINITE) (|FileCategory| . FILECAT) (|FileNameCategory| . FNCAT) (|FiniteAbelianMonoidRing| . FAMR) (|FiniteAlgebraicExtensionField| . FAXF) (|FiniteDivisorCategory| . FDIVCAT) (|FiniteFieldCategory| . FFIELDC) (|FiniteLinearAggregate| . FLAGG) (|FiniteRankNonAssociativeAlgebra| . FINAALG) (|FiniteRankAlgebra| . FINRALG) (|FiniteSetAggregate| . FSAGG) (|FloatingPointSystem| . FPS) (|FramedAlgebra| . FRAMALG) (|FramedNonAssociativeAlgebra| . FRNAALG) (|FramedNonAssociativeAlgebraFunctions2| . FRNAAF2) (|FreeAbelianMonoidCategory| . FAMONC) (|FreeLieAlgebra| . FLALG) (|FreeModuleCat| . FMCAT) (|FullyEvalableOver| . FEVALAB) (|FullyLinearlyExplicitRingOver| . FLINEXP) (|FullyPatternMatchable| . FPATMAB) (|FullyRetractableTo| . FRETRCT) (|FunctionFieldCategory| . FFCAT) (|FunctionSpace| . FS) (|GcdDomain| . GCDDOM) (|GradedAlgebra| . GRALG) (|GradedModule| . GRMOD) (|Group| . GROUP) (|HomogeneousAggregate| . HOAGG) (|HyperbolicFunctionCategory| . HYPCAT) (|IndexedAggregate| . IXAGG) (|IndexedDirectProductCategory| . IDPC) (|InnerEvalable| . IEVALAB) (|IntegerNumberSystem| . INS) (|IntegralDomain| . INTDOM) (|IntervalCategory| . INTCAT) (|KeyedDictionary| . KDAGG) (|LazyStreamAggregate| . LZSTAGG) (|LeftAlgebra| . LALG) (|LeftModule| . LMODULE) (|LieAlgebra| . LIECAT) (|LinearAggregate| . LNAGG) (|LinearlyExplicitRingOver| . LINEXP) (|LinearOrdinaryDifferentialOperatorCategory| . LODOCAT) (|LiouvillianFunctionCategory| . LFCAT) (|ListAggregate| . LSAGG) (|Logic| . LOGIC) (|MatrixCategory| . MATCAT) (|Module| . MODULE) (|Monad| . MONAD) (|MonadWithUnit| . MONADWU) (|Monoid| . MONOID) (|MonogenicAlgebra| . MONOGEN) (|MonogenicLinearOperator| . MLO) (|MultiDictionary| . MDAGG) (|MultisetAggregate| . MSETAGG) (|MultivariateTaylorSeriesCategory| . MTSCAT) (|NonAssociativeAlgebra| . NAALG) (|NonAssociativeRing| . NASRING) (|NonAssociativeRng| . NARNG) (|NormalizedTriangularSetCategory| . NTSCAT) (|Object| . OBJECT) (|OctonionCategory| . OC) (|OneDimensionalArrayAggregate| . A1AGG) (|OpenMath| . OM) (|OrderedAbelianGroup| . OAGROUP) (|OrderedAbelianMonoid| . OAMON) (|OrderedAbelianMonoidSup| . OAMONS) (|OrderedAbelianSemiGroup| . OASGP) (|OrderedCancellationAbelianMonoid| . OCAMON) (|OrderedFinite| . ORDFIN) (|OrderedIntegralDomain| . OINTDOM) (|OrderedMonoid| . ORDMON) (|OrderedMultisetAggregate| . OMSAGG) (|OrderedRing| . ORDRING) (|OrderedSet| . ORDSET) (|PAdicIntegerCategory| . PADICCT) (|PartialDifferentialRing| . PDRING) (|PartialTranscendentalFunctions| . PTRANFN) (|Patternable| . PATAB) (|PatternMatchable| . PATMAB) (|PermutationCategory| . PERMCAT) (|PlottablePlaneCurveCategory| . PPCURVE) (|PlottableSpaceCurveCategory| . PSCURVE) (|PointCategory| . PTCAT) (|PolynomialCategory| . POLYCAT) (|PolynomialFactorizationExplicit| . PFECAT) (|PolynomialSetCategory| . PSETCAT) (|PowerSeriesCategory| . PSCAT) (|PrimitiveFunctionCategory| . PRIMCAT) (|PrincipalIdealDomain| . PID) (|PriorityQueueAggregate| . PRQAGG) (|QuaternionCategory| . QUATCAT) (|QueueAggregate| . QUAGG) (|QuotientFieldCategory| . QFCAT) (|RadicalCategory| . RADCAT) (|RealClosedField| . RCFIELD) (|RealConstant| . REAL) (|RealNumberSystem| . RNS) (|RealRootCharacterizationCategory| . RRCC) (|RectangularMatrixCategory| . RMATCAT) (|RecursiveAggregate| . RCAGG) (|RecursivePolynomialCategory| . RPOLCAT) (|RegularChain| . RGCHAIN) (|RegularTriangularSetCategory| . RSETCAT) (|RetractableTo| . RETRACT) (|RightModule| . RMODULE) (|Ring| . RING) (|Rng| . RNG) (|SegmentCategory| . SEGCAT) (|SegmentExpansionCategory| . SEGXCAT) (|SemiGroup| . SGROUP) (|SetAggregate| . SETAGG) (|SetCategory| . SETCAT) (|SExpressionCategory| . SEXCAT) (|SpecialFunctionCategory| . SPFCAT) (|SquareFreeNormalizedTriangularSetCategory| . SNTSCAT) (|SquareFreeRegularTriangularSetCategory| . SFRTCAT) (|SquareMatrixCategory| . SMATCAT) (|StackAggregate| . SKAGG) (|StepThrough| . STEP) (|StreamAggregate| . STAGG) (|StringAggregate| . SRAGG) (|StringCategory| . STRICAT) (|StructuralConstantsPackage| . SCPKG) (|TableAggregate| . TBAGG) (|ThreeSpaceCategory| . SPACEC) (|TranscendentalFunctionCategory| . TRANFUN) (|TriangularSetCategory| . TSETCAT) (|TrigonometricFunctionCategory| . TRIGCAT) (|TwoDimensionalArrayCategory| . ARR2CAT) (|Type| . TYPE) (|UnaryRecursiveAggregate| . URAGG) (|UniqueFactorizationDomain| . UFD) (|UnivariateLaurentSeriesCategory| . ULSCAT) (|UnivariateLaurentSeriesConstructorCategory| . ULSCCAT) (|UnivariatePolynomialCategory| . UPOLYC) (|UnivariatePowerSeriesCategory| . UPSCAT) (|UnivariatePuiseuxSeriesCategory| . UPXSCAT) (|UnivariatePuiseuxSeriesConstructorCategory| . UPXSCCA) (|UnivariateSkewPolynomialCategory| . OREPCAT) (|UnivariateTaylorSeriesCategory| . UTSCAT) (|VectorCategory| . VECTCAT) (|VectorSpace| . VSPACE) (|XAlgebra| . XALG) (|XFreeAlgebra| . XFALG) (|XPolynomialsCat| . XPOLYC) (|ZeroDimensionalSolvePackage| . ZDSOLVE)) (|Hidden| (|AlgebraicFunction| . AF) (|AlgebraicFunctionField| . ALGFF) (|AlgebraicHermiteIntegration| . INTHERAL) (|AlgebraicIntegrate| . INTALG) (|AlgebraicIntegration| . INTAF) (|AnonymousFunction| . ANON) (|AntiSymm| . ANTISYM) (|ApplyRules| . APPRULE) (|ApplyUnivariateSkewPolynomial| . APPLYORE) (|ArrayStack| . ASTACK) (|AssociatedEquations| . ASSOCEQ) (|AssociationList| . ALIST) (|Automorphism| . AUTOMOR) (|BalancedFactorisation| . BALFACT) (|BalancedPAdicInteger| . BPADIC) (|BalancedPAdicRational| . BPADICRT) (|BezoutMatrix| . BEZOUT) (|BoundIntegerRoots| . BOUNDZRO) (|BrillhartTests| . BRILL) (|ChangeOfVariable| . CHVAR) (|CharacteristicPolynomialInMonogenicalAlgebra| . CPIMA) (|ChineseRemainderToolsForIntegralBases| . IBACHIN) (|CoerceVectorMatrixPackage| . CVMP) (|CombinatorialFunction| . COMBF) (|CommonOperators| . COMMONOP) (|CommuteUnivariatePolynomialCategory| . COMMUPC) (|ComplexIntegerSolveLinearPolynomialEquation| . CINTSLPE) (|ComplexPattern| . COMPLPAT) (|ComplexPatternMatch| . CPMATCH) (|ComplexRootFindingPackage| . CRFP) (|ConstantLODE| . ODECONST) (|CyclicStreamTools| . CSTTOOLS) (|CyclotomicPolynomialPackage| . CYCLOTOM) (|DefiniteIntegrationTools| . DFINTTLS) (|DegreeReductionPackage| . DEGRED) (|DeRhamComplex| . DERHAM) (|DifferentialSparseMultivariatePolynomial| . DSMP) (|DirectProduct| . DIRPROD) (|DirectProductMatrixModule| . DPMM) (|DirectProductModule| . DPMO) (|DiscreteLogarithmPackage| . DLP) (|DistributedMultivariatePolynomial| . DMP) (|DoubleResultantPackage| . DBLRESP) (|DrawOptionFunctions0| . DROPT0) (|DrawOptionFunctions1| . DROPT1) (|ElementaryFunction| . EF) (|ElementaryFunctionsUnivariateLaurentSeries| . EFULS) (|ElementaryFunctionsUnivariatePuiseuxSeries| . EFUPXS) (|ElementaryIntegration| . INTEF) (|ElementaryRischDE| . RDEEF) (|ElementaryRischDESystem| . RDEEFS) (|EllipticFunctionsUnivariateTaylorSeries| . ELFUTS) (|EqTable| . EQTBL) (|EuclideanModularRing| . EMR) (|EvaluateCycleIndicators| . EVALCYC) (|ExponentialExpansion| . EXPEXPAN) (|ExponentialOfUnivariatePuiseuxSeries| . EXPUPXS) (|ExpressionSpaceFunctions1| . ES1) (|ExpressionTubePlot| . EXPRTUBE) (|ExtAlgBasis| . EAB) (|FactoredFunctions| . FACTFUNC) (|FactoredFunctionUtilities| . FRUTIL) (|FactoringUtilities| . FACUTIL) (|FGLMIfCanPackage| . FGLMICPK) (|FindOrderFinite| . FORDER) (|FiniteDivisor| . FDIV) (|FiniteFieldCyclicGroupExtension| . FFCGX) (|FiniteFieldCyclicGroupExtensionByPolynomial| . FFCGP) (|FiniteFieldExtension| . FFX) (|FiniteFieldExtensionByPolynomial| . FFP) (|FiniteFieldFunctions| . FFF) (|FiniteFieldNormalBasisExtension| . FFNBX) (|FiniteFieldNormalBasisExtensionByPolynomial| . FFNBP) (|FiniteFieldPolynomialPackage| . FFPOLY) (|FiniteFieldSolveLinearPolynomialEquation| . FFSLPE) (|FormalFraction| . FORMAL) (|FourierComponent| . FCOMP) (|FractionalIdeal| . FRIDEAL) (|FramedModule| . FRMOD) (|FreeAbelianGroup| . FAGROUP) (|FreeAbelianMonoid| . FAMONOID) (|FreeGroup| . FGROUP) (|FreeModule| . FM) (|FreeModule1| . FM1) (|FreeMonoid| . FMONOID) (|FunctionalSpecialFunction| . FSPECF) (|FunctionCalled| . FUNCTION) (|FunctionFieldIntegralBasis| . FFINTBAS) (|FunctionSpaceReduce| . FSRED) (|FunctionSpaceToUnivariatePowerSeries| . FS2UPS) (|FunctionSpaceToExponentialExpansion| . FS2EXPXP) (|FunctionSpaceUnivariatePolynomialFactor| . FSUPFACT) (|GaloisGroupFactorizationUtilities| . GALFACTU) (|GaloisGroupFactorizer| . GALFACT) (|GaloisGroupPolynomialUtilities| . GALPOLYU) (|GaloisGroupUtilities| . GALUTIL) (|GeneralHenselPackage| . GHENSEL) (|GeneralDistributedMultivariatePolynomial| . GDMP) (|GeneralPolynomialGcdPackage| . GENPGCD) (|GeneralSparseTable| . GSTBL) (|GenericNonAssociativeAlgebra| . GCNAALG) (|GenExEuclid| . GENEEZ) (|GeneralizedMultivariateFactorize| . GENMFACT) (|GeneralModulePolynomial| . GMODPOL) (|GeneralPolynomialSet| . GPOLSET) (|GeneralTriangularSet| . GTSET) (|GenUFactorize| . GENUFACT) (|GenusZeroIntegration| . INTG0) (|GosperSummationMethod| . GOSPER) (|GraphImage| . GRIMAGE) (|GrayCode| . GRAY) (|GroebnerInternalPackage| . GBINTERN) (|GroebnerSolve| . GROEBSOL) (|HashTable| . HASHTBL) (|Heap| . HEAP) (|HeuGcd| . HEUGCD) (|HomogeneousDistributedMultivariatePolynomial| . HDMP) (|HyperellipticFiniteDivisor| . HELLFDIV) (|IncrementingMaps| . INCRMAPS) (|IndexedBits| . IBITS) (|IndexedDirectProductAbelianGroup| . IDPAG) (|IndexedDirectProductAbelianMonoid| . IDPAM) (|IndexedDirectProductObject| . IDPO) (|IndexedDirectProductOrderedAbelianMonoid| . IDPOAM) (|IndexedDirectProductOrderedAbelianMonoidSup| . IDPOAMS) (|IndexedExponents| . INDE) (|IndexedFlexibleArray| . IFARRAY) (|IndexedList| . ILIST) (|IndexedMatrix| . IMATRIX) (|IndexedOneDimensionalArray| . IARRAY1) (|IndexedString| . ISTRING) (|IndexedTwoDimensionalArray| . IARRAY2) (|IndexedVector| . IVECTOR) (|InnerAlgFactor| . IALGFACT) (|InnerAlgebraicNumber| . IAN) (|InnerCommonDenominator| . ICDEN) (|InnerFiniteField| . IFF) (|InnerFreeAbelianMonoid| . IFAMON) (|InnerIndexedTwoDimensionalArray| . IIARRAY2) (|InnerMatrixLinearAlgebraFunctions| . IMATLIN) (|InnerMatrixQuotientFieldFunctions| . IMATQF) (|InnerModularGcd| . INMODGCD) (|InnerMultFact| . INNMFACT) (|InnerNormalBasisFieldFunctions| . INBFF) (|InnerNumericEigenPackage| . INEP) (|InnerNumericFloatSolvePackage| . INFSP) (|InnerPAdicInteger| . IPADIC) (|InnerPolySign| . INPSIGN) (|InnerPolySum| . ISUMP) (|InnerPrimeField| . IPF) (|InnerSparseUnivariatePowerSeries| . ISUPS) (|InnerTable| . INTABL) (|InnerTaylorSeries| . ITAYLOR) (|InnerTrigonometricManipulations| . ITRIGMNP) (|InputForm| . INFORM) (|InputFormFunctions1| . INFORM1) (|IntegerBits| . INTBIT) (|IntegerFactorizationPackage| . INTFACT) (|IntegerMod| . ZMOD) (|IntegerSolveLinearPolynomialEquation| . INTSLPE) (|IntegralBasisPolynomialTools| . IBPTOOLS) (|IntegralBasisTools| . IBATOOL) (|IntegrationResult| . IR) (|IntegrationTools| . INTTOOLS) (|InternalPrintPackage| . IPRNTPK) (|InternalRationalUnivariateRepresentationPackage| . IRURPK) (|IrredPolyOverFiniteField| . IRREDFFX) (|Kernel| . KERNEL) (|Kovacic| . KOVACIC) (|LaurentPolynomial| . LAUPOL) (|LeadingCoefDetermination| . LEADCDET) (|LexTriangularPackage| . LEXTRIPK) (|LieExponentials| . LEXP) (|LiePolynomial| . LPOLY) (|LinearDependence| . LINDEP) (|LinearOrdinaryDifferentialOperatorFactorizer| . LODOF) (|LinearOrdinaryDifferentialOperator1| . LODO1) (|LinearOrdinaryDifferentialOperator2| . LODO2) (|LinearOrdinaryDifferentialOperatorsOps| . LODOOPS) (|LinearPolynomialEquationByFractions| . LPEFRAC) (|LinGroebnerPackage| . LGROBP) (|LiouvillianFunction| . LF) (|ListMonoidOps| . LMOPS) (|ListMultiDictionary| . LMDICT) (|LocalAlgebra| . LA) (|Localize| . LO) (|LyndonWord| . LWORD) (|Magma| . MAGMA) (|MakeBinaryCompiledFunction| . MKBCFUNC) (|MakeCachableSet| . MKCHSET) (|MakeUnaryCompiledFunction| . MKUCFUNC) (|MappingPackageInternalHacks1| . MAPHACK1) (|MappingPackageInternalHacks2| . MAPHACK2) (|MappingPackageInternalHacks3| . MAPHACK3) (|MeshCreationRoutinesForThreeDimensions| . MESH) (|ModMonic| . MODMON) (|ModularField| . MODFIELD) (|ModularHermitianRowReduction| . MHROWRED) (|ModularRing| . MODRING) (|ModuleMonomial| . MODMONOM) (|MoebiusTransform| . MOEBIUS) (|MonoidRing| . MRING) (|MonomialExtensionTools| . MONOTOOL) (|MPolyCatPolyFactorizer| . MPCPF) (|MPolyCatFunctions3| . MPC3) (|MRationalFactorize| . MRATFAC) (|MultipleMap| . MMAP) (|MultivariateLifting| . MLIFT) (|MultivariateSquareFree| . MULTSQFR) (|HomogeneousDirectProduct| . HDP) (|NewSparseMultivariatePolynomial| . NSMP) (|NewSparseUnivariatePolynomial| . NSUP) (|NewSparseUnivariatePolynomialFunctions2| . NSUP2) (|NonCommutativeOperatorDivision| . NCODIV) (|NewtonInterpolation| . NEWTON) (|None| . NONE) (|NonLinearFirstOrderODESolver| . NODE1) (|NonLinearSolvePackage| . NLINSOL) (|NormRetractPackage| . NORMRETR) (|NPCoef| . NPCOEF) (|NumberFormats| . NUMFMT) (|NumberFieldIntegralBasis| . NFINTBAS) (|NumericTubePlot| . NUMTUBE) (|ODEIntegration| . ODEINT) (|ODETools| . ODETOOLS) (|Operator| . OP) (|OppositeMonogenicLinearOperator| . OMLO) (|OrderedDirectProduct| . ODP) (|OrderedFreeMonoid| . OFMONOID) (|OrderedVariableList| . OVAR) (|OrderingFunctions| . ORDFUNS) (|OrderlyDifferentialPolynomial| . ODPOL) (|OrderlyDifferentialVariable| . ODVAR) (|OrdinaryWeightedPolynomials| . OWP) (|OutputForm| . OUTFORM) (|PadeApproximants| . PADE) (|PAdicInteger| . PADIC) (|PAdicRational| . PADICRAT) (|PAdicRationalConstructor| . PADICRC) (|PAdicWildFunctionFieldIntegralBasis| . PWFFINTB) (|ParadoxicalCombinatorsForStreams| . YSTREAM) (|ParametricLinearEquations| . PLEQN) (|PartialFractionPackage| . PFRPAC) (|Partition| . PRTITION) (|Pattern| . PATTERN) (|PatternFunctions1| . PATTERN1) (|PatternMatchFunctionSpace| . PMFS) (|PatternMatchIntegerNumberSystem| . PMINS) (|PatternMatchIntegration| . INTPM) (|PatternMatchKernel| . PMKERNEL) (|PatternMatchListAggregate| . PMLSAGG) (|PatternMatchListResult| . PATLRES) (|PatternMatchPolynomialCategory| . PMPLCAT) (|PatternMatchPushDown| . PMDOWN) (|PatternMatchQuotientFieldCategory| . PMQFCAT) (|PatternMatchResult| . PATRES) (|PatternMatchSymbol| . PMSYM) (|PatternMatchTools| . PMTOOLS) (|PlaneAlgebraicCurvePlot| . ACPLOT) (|Plot| . PLOT) (|PlotFunctions1| . PLOT1) (|PlotTools| . PLOTTOOL) (|Plot3D| . PLOT3D) (|PoincareBirkhoffWittLyndonBasis| . PBWLB) (|Point| . POINT) (|PointsOfFiniteOrder| . PFO) (|PointsOfFiniteOrderRational| . PFOQ) (|PointsOfFiniteOrderTools| . PFOTOOLS) (|PointPackage| . PTPACK) (|PolToPol| . POLTOPOL) (|PolynomialCategoryLifting| . POLYLIFT) (|PolynomialCategoryQuotientFunctions| . POLYCATQ) (|PolynomialFactorizationByRecursion| . PFBR) (|PolynomialFactorizationByRecursionUnivariate| . PFBRU) (|PolynomialGcdPackage| . PGCD) (|PolynomialInterpolation| . PINTERP) (|PolynomialInterpolationAlgorithms| . PINTERPA) (|PolynomialNumberTheoryFunctions| . PNTHEORY) (|PolynomialRing| . PR) (|PolynomialRoots| . POLYROOT) (|PolynomialSetUtilitiesPackage| . PSETPK) (|PolynomialSolveByFormulas| . SOLVEFOR) (|PolynomialSquareFree| . PSQFR) (|PrecomputedAssociatedEquations| . PREASSOC) (|PrimitiveArray| . PRIMARR) (|PrimitiveElement| . PRIMELT) (|PrimitiveRatDE| . ODEPRIM) (|PrimitiveRatRicDE| . ODEPRRIC) (|Product| . PRODUCT) (|PseudoRemainderSequence| . PRS) (|PseudoLinearNormalForm| . PSEUDLIN) (|PureAlgebraicIntegration| . INTPAF) (|PureAlgebraicLODE| . ODEPAL) (|PushVariables| . PUSHVAR) (|QuasiAlgebraicSet| . QALGSET) (|QuasiAlgebraicSet2| . QALGSET2) (|RadicalFunctionField| . RADFF) (|RandomDistributions| . RDIST) (|RandomFloatDistributions| . RFDIST) (|RandomIntegerDistributions| . RIDIST) (|RationalFactorize| . RATFACT) (|RationalIntegration| . INTRAT) (|RationalInterpolation| . RINTERP) (|RationalLODE| . ODERAT) (|RationalRicDE| . ODERTRIC) (|RationalUnivariateRepresentationPackage| . RURPK) (|RealSolvePackage| . REALSOLV) (|RectangularMatrix| . RMATRIX) (|ReducedDivisor| . RDIV) (|ReduceLODE| . ODERED) (|ReductionOfOrder| . REDORDER) (|Reference| . REF) (|RepeatedDoubling| . REPDB) (|RepeatedSquaring| . REPSQ) (|ResidueRing| . RESRING) (|RetractSolvePackage| . RETSOL) (|RuleCalled| . RULECOLD) (|SetOfMIntegersInOneToN| . SETMN) (|SExpression| . SEX) (|SExpressionOf| . SEXOF) (|SequentialDifferentialPolynomial| . SDPOL) (|SequentialDifferentialVariable| . SDVAR) (|SimpleAlgebraicExtension| . SAE) (|SingletonAsOrderedSet| . SAOS) (|SortedCache| . SCACHE) (|SortPackage| . SORTPAK) (|SparseMultivariatePolynomial| . SMP) (|SparseMultivariateTaylorSeries| . SMTS) (|SparseTable| . STBL) (|SparseUnivariatePolynomial| . SUP) (|SparseUnivariateSkewPolynomial| . ORESUP) (|SparseUnivariateLaurentSeries| . SULS) (|SparseUnivariatePuiseuxSeries| . SUPXS) (|SparseUnivariateTaylorSeries| . SUTS) (|SplitHomogeneousDirectProduct| . SHDP) (|SplittingNode| . SPLNODE) (|SplittingTree| . SPLTREE) (|SquareMatrix| . SQMATRIX) (|Stack| . STACK) (|StorageEfficientMatrixOperations| . MATSTOR) (|StreamInfiniteProduct| . STINPROD) (|StreamTaylorSeriesOperations| . STTAYLOR) (|StreamTranscendentalFunctions| . STTF) (|StreamTranscendentalFunctionsNonCommutative| . STTFNC) (|StringTable| . STRTBL) (|SubResultantPackage| . SUBRESP) (|SubSpace| . SUBSPACE) (|SubSpaceComponentProperty| . COMPPROP) (|SuchThat| . SUCH) (|SupFractionFactorizer| . SUPFRACF) (|SymmetricFunctions| . SYMFUNC) (|SymmetricPolynomial| . SYMPOLY) (|SystemODESolver| . ODESYS) (|Table| . TABLE) (|TableauxBumpers| . TABLBUMP) (|TabulatedComputationPackage| . TBCMPPK) (|TangentExpansions| . TANEXP) (|ToolsForSign| . TOOLSIGN) (|TranscendentalHermiteIntegration| . INTHERTR) (|TranscendentalIntegration| . INTTR) (|TranscendentalRischDE| . RDETR) (|TranscendentalRischDESystem| . RDETRS) (|TransSolvePackageService| . SOLVESER) (|TriangularMatrixOperations| . TRIMAT) (|TubePlot| . TUBE) (|TubePlotTools| . TUBETOOL) (|Tuple| . TUPLE) (|TwoDimensionalArray| . ARRAY2) (|TwoDimensionalPlotClipping| . CLIP) (|TwoDimensionalViewport| . VIEW2D) (|TwoFactorize| . TWOFACT) (|UnivariateFactorize| . UNIFACT) (|UnivariateLaurentSeries| . ULS) (|UnivariateLaurentSeriesConstructor| . ULSCONS) (|UnivariatePolynomialDecompositionPackage| . UPDECOMP) (|UnivariatePolynomialDivisionPackage| . UPDIVP) (|UnivariatePolynomialSquareFree| . UPSQFREE) (|UnivariatePuiseuxSeries| . UPXS) (|UnivariatePuiseuxSeriesConstructor| . UPXSCONS) (|UnivariatePuiseuxSeriesWithExponentialSingularity| . UPXSSING) (|UnivariateSkewPolynomial| . OREUP) (|UnivariateSkewPolynomialCategoryOps| . OREPCTO) (|UnivariateTaylorSeries| . UTS) (|UnivariateTaylorSeriesODESolver| . UTSODE) (|UserDefinedPartialOrdering| . UDPO) (|UTSodetools| . UTSODETL) (|Variable| . VARIABLE) (|ViewportPackage| . VIEW) (|WeierstrassPreparation| . WEIER) (|WeightedPolynomials| . WP) (|WildFunctionFieldIntegralBasis| . WFFINTBS) (|XDistributedPolynomial| . XDPOLY) (|XExponentialPackage| . XEXPPKG) (|XPBWPolynomial| . XPBWPOLY) (|XPolynomial| . XPOLY) (|XPolynomialRing| . XPR) (|XRecursivePolynomial| . XRPOLY)) (|defaults| (|AbelianGroup&| . ABELGRP-) (|AbelianMonoid&| . ABELMON-) (|AbelianMonoidRing&| . AMR-) (|AbelianSemiGroup&| . ABELSG-) (|Aggregate&| . AGG-) (|Algebra&| . ALGEBRA-) (|AlgebraicallyClosedField&| . ACF-) (|AlgebraicallyClosedFunctionSpace&| . ACFS-) (|ArcTrigonometricFunctionCategory&| . ATRIG-) (|BagAggregate&| . BGAGG-) (|BasicType&| . BASTYPE-) (|BinaryRecursiveAggregate&| . BRAGG-) (|BinaryTreeCategory&| . BTCAT-) (|BitAggregate&| . BTAGG-) (|Collection&| . CLAGG-) (|ComplexCategory&| . COMPCAT-) (|Dictionary&| . DIAGG-) (|DictionaryOperations&| . DIOPS-) (|DifferentialExtension&| . DIFEXT-) (|DifferentialPolynomialCategory&| . DPOLCAT-) (|DifferentialRing&| . DIFRING-) (|DifferentialVariableCategory&| . DVARCAT-) (|DirectProductCategory&| . DIRPCAT-) (|DivisionRing&| . DIVRING-) (|ElementaryFunctionCategory&| . ELEMFUN-) (|EltableAggregate&| . ELTAGG-) (|EuclideanDomain&| . EUCDOM-) (|Evalable&| . EVALAB-) (|ExpressionSpace&| . ES-) (|ExtensibleLinearAggregate&| . ELAGG-) (|ExtensionField&| . XF-) (|Field&| . FIELD-) (|FieldOfPrimeCharacteristic&| . FPC-) (|FiniteAbelianMonoidRing&| . FAMR-) (|FiniteAlgebraicExtensionField&| . FAXF-) (|FiniteDivisorCategory&| . FDIVCAT-) (|FiniteFieldCategory&| . FFIELDC-) (|FiniteLinearAggregate&| . FLAGG-) (|FiniteSetAggregate&| . FSAGG-) (|FiniteRankAlgebra&| . FINRALG-) (|FiniteRankNonAssociativeAlgebra&| . FINAALG-) (|FloatingPointSystem&| . FPS-) (|FramedAlgebra&| . FRAMALG-) (|FramedNonAssociativeAlgebra&| . FRNAALG-) (|FullyEvalableOver&| . FEVALAB-) (|FullyLinearlyExplicitRingOver&| . FLINEXP-) (|FullyRetractableTo&| . FRETRCT-) (|FunctionFieldCategory&| . FFCAT-) (|FunctionSpace&| . FS-) (|GcdDomain&| . GCDDOM-) (|GradedAlgebra&| . GRALG-) (|GradedModule&| . GRMOD-) (|Group&| . GROUP-) (|HomogeneousAggregate&| . HOAGG-) (|HyperbolicFunctionCategory&| . HYPCAT-) (|IndexedAggregate&| . IXAGG-) (|InnerEvalable&| . IEVALAB-) (|IntegerNumberSystem&| . INS-) (|IntegralDomain&| . INTDOM-) (|KeyedDictionary&| . KDAGG-) (|LazyStreamAggregate&| . LZSTAGG-) (|LeftAlgebra&| . LALG-) (|LieAlgebra&| . LIECAT-) (|LinearAggregate&| . LNAGG-) (|ListAggregate&| . LSAGG-) (|Logic&| . LOGIC-) (|LinearOrdinaryDifferentialOperatorCategory&| . LODOCAT-) (|MatrixCategory&| . MATCAT-) (|Module&| . MODULE-) (|Monad&| . MONAD-) (|MonadWithUnit&| . MONADWU-) (|Monoid&| . MONOID-) (|MonogenicAlgebra&| . MONOGEN-) (|NonAssociativeAlgebra&| . NAALG-) (|NonAssociativeRing&| . NASRING-) (|NonAssociativeRng&| . NARNG-) (|OctonionCategory&| . OC-) (|OneDimensionalArrayAggregate&| . A1AGG-) (|OrderedRing&| . ORDRING-) (|OrderedSet&| . ORDSET-) (|PartialDifferentialRing&| . PDRING-) (|PolynomialCategory&| . POLYCAT-) (|PolynomialFactorizationExplicit&| . PFECAT-) (|PolynomialSetCategory&| . PSETCAT-) (|PowerSeriesCategory&| . PSCAT-) (|QuaternionCategory&| . QUATCAT-) (|QuotientFieldCategory&| . QFCAT-) (|RadicalCategory&| . RADCAT-) (|RealClosedField&| . RCFIELD-) (|RealNumberSystem&| . RNS-) (|RealRootCharacterizationCategory&| . RRCC-) (|RectangularMatrixCategory&| . RMATCAT-) (|RecursiveAggregate&| . RCAGG-) (|RecursivePolynomialCategory&| . RPOLCAT-) (|RegularTriangularSetCategory&| . RSETCAT-) (|RetractableTo&| . RETRACT-) (|Ring&| . RING-) (|SemiGroup&| . SGROUP-) (|SetAggregate&| . SETAGG-) (|SetCategory&| . SETCAT-) (|SquareMatrixCategory&| . SMATCAT-) (|StreamAggregate&| . STAGG-) (|StringAggregate&| . SRAGG-) (|TableAggregate&| . TBAGG-) (|TranscendentalFunctionCategory&| . TRANFUN-) (|TriangularSetCategory&| . TSETCAT-) (|TrigonometricFunctionCategory&| . TRIGCAT-) (|TwoDimensionalArrayCategory&| . ARR2CAT-) (|UnaryRecursiveAggregate&| . URAGG-) (|UniqueFactorizationDomain&| . UFD-) (|UnivariateLaurentSeriesConstructorCategory&| . ULSCCAT-) (|UnivariatePolynomialCategory&| . UPOLYC-) (|UnivariatePowerSeriesCategory&| . UPSCAT-) (|UnivariatePuiseuxSeriesConstructorCategory&| . UPXSCCA-) (|UnivariateSkewPolynomialCategory&| . OREPCAT-) (|UnivariateTaylorSeriesCategory&| . UTSCAT-) (|VectorCategory&| . VECTCAT-) (|VectorSpace&| . VSPACE-)))
+--RValue = ((|basic| (|AlgebraicManipulations| . ALGMANIP) (|AlgebraicNumber| . AN) (|AlgFactor| . ALGFACT) (|AlgebraicMultFact| . ALGMFACT) (|AlgebraPackage| . ALGPKG) (|AlgebraGivenByStructuralConstants| . ALGSC) (|Any| . ANY) (|AnyFunctions1| . ANY1) (|ApplicationProgramInterface| . API) (|ArrayStack| . ASTACK) (|AssociatedJordanAlgebra| . JORDAN) (|AssociatedLieAlgebra| . LIE) (|AttachPredicates| . PMPRED) (|AxiomServer| . AXSERV) (|BalancedBinaryTree| . BBTREE) (|BasicOperator| . BOP) (|BasicOperatorFunctions1| . BOP1) (|Bezier| . BEZIER) (|BinaryExpansion| . BINARY) (|BinaryFile| . BINFILE) (|BinarySearchTree| . BSTREE) (|BinaryTournament| . BTOURN) (|BinaryTree| . BTREE) (|Bits| . BITS) (|Boolean| . BOOLEAN) (|CardinalNumber| . CARD) (|CartesianTensor| . CARTEN) (|CartesianTensorFunctions2| . CARTEN2) (|Character| . CHAR) (|CharacterClass| . CCLASS) (|CharacteristicPolynomialPackage| . CHARPOL) (|CliffordAlgebra| . CLIF) (|Color| . COLOR) (|CommonDenominator| . CDEN) (|Commutator| . COMM) (|Complex| . COMPLEX) (|ComplexFactorization| . COMPFACT) (|ComplexFunctions2| . COMPLEX2) (|ComplexRootPackage| . CMPLXRT) (|ComplexTrigonometricManipulations| . CTRIGMNP) (|ContinuedFraction| . CONTFRAC) (|CoordinateSystems| . COORDSYS) (|CRApackage| . CRAPACK) (|CycleIndicators| . CYCLES) (|Database| . DBASE) (|DataList| . DLIST) (|DecimalExpansion| . DECIMAL) (|DenavitHartenbergMatrix| . DHMATRIX) (|Dequeue| . DEQUEUE) (|DiophantineSolutionPackage| . DIOSP) (|DirectProductFunctions2| . DIRPROD2) (|DisplayPackage| . DISPLAY) (|DistinctDegreeFactorize| . DDFACT) (|DoubleFloat| . DFLOAT) (|DoubleFloatSpecialFunctions| . DFSFUN) (|DrawComplex| . DRAWCX) (|DrawNumericHack| . DRAWHACK) (|DrawOption| . DROPT) (|EigenPackage| . EP) (|ElementaryFunctionDefiniteIntegration| . DEFINTEF) (|ElementaryFunctionLODESolver| . LODEEF) (|ElementaryFunctionODESolver| . ODEEF) (|ElementaryFunctionSign| . SIGNEF) (|ElementaryFunctionStructurePackage| . EFSTRUC) (|Equation| . EQ) (|EquationFunctions2| . EQ2) (|ErrorFunctions| . ERROR) (|EuclideanGroebnerBasisPackage| . GBEUCLID) (|Exit| . EXIT) (|Expression| . EXPR) (|ExpressionFunctions2| . EXPR2) (|ExpressionSolve| . EXPRSOL) (|ExpressionSpaceFunctions2| . ES2) (|ExpressionSpaceODESolver| . EXPRODE) (|ExpressionToOpenMath| . OMEXPR) (|ExpressionToUnivariatePowerSeries| . EXPR2UPS) (|Factored| . FR) (|FactoredFunctions2| . FR2) (|File| . FILE) (|FileName| . FNAME) (|FiniteAbelianMonoidRingFunctions2| . FAMR2) (|FiniteDivisorFunctions2| . FDIV2) (|FiniteField| . FF) (|FiniteFieldCyclicGroup| . FFCG) (|FiniteFieldPolynomialPackage2| . FFPOLY2) (|FiniteFieldNormalBasis| . FFNB) (|FiniteFieldHomomorphisms| . FFHOM) (|FiniteLinearAggregateFunctions2| . FLAGG2) (|FiniteLinearAggregateSort| . FLASORT) (|FiniteSetAggregateFunctions2| . FSAGG2) (|FlexibleArray| . FARRAY) (|Float| . FLOAT) (|FloatingRealPackage| . FLOATRP) (|FloatingComplexPackage| . FLOATCP) (|FourierSeries| . FSERIES) (|Fraction| . FRAC) (|FractionalIdealFunctions2| . FRIDEAL2) (|FractionFreeFastGaussian| . FFFG) (|FractionFreeFastGaussianFractions| . FFFGF) (|FractionFunctions2| . FRAC2) (|FreeNilpotentLie| . FNLA) (|FullPartialFractionExpansion| . FPARFRAC) (|FunctionFieldCategoryFunctions2| . FFCAT2) (|FunctionSpaceAssertions| . PMASSFS) (|FunctionSpaceAttachPredicates| . PMPREDFS) (|FunctionSpaceComplexIntegration| . FSCINT) (|FunctionSpaceFunctions2| . FS2) (|FunctionSpaceIntegration| . FSINT) (|FunctionSpacePrimitiveElement| . FSPRMELT) (|FunctionSpaceSum| . SUMFS) (|GaussianFactorizationPackage| . GAUSSFAC) (|GeneralUnivariatePowerSeries| . GSERIES) (|GenerateUnivariatePowerSeries| . GENUPS) (|GraphicsDefaults| . GRDEF) (|GroebnerPackage| . GB) (|GroebnerFactorizationPackage| . GBF) (|Guess| . GUESS) (|GuessAlgebraicNumber| . GUESSAN) (|GuessFinite| . GUESSF) (|GuessFiniteFunctions| . GUESSF1) (|GuessInteger| . GUESSINT) (|GuessOption| . GOPT) (|GuessOptionFunctions0| . GOPT0) (|GuessPolynomial| . GUESSP) (|GuessUnivariatePolynomial| . GUESSUP) (|HallBasis| . HB) (|Heap| . HEAP) (|HexadecimalExpansion| . HEXADEC) (|IndexCard| . ICARD) (|IdealDecompositionPackage| . IDECOMP) (|InfiniteProductCharacteristicZero| . INFPROD0) (|InfiniteProductFiniteField| . INPRODFF) (|InfiniteProductPrimeField| . INPRODPF) (|InfiniteTuple| . ITUPLE) (|InfiniteTupleFunctions2| . ITFUN2) (|InfiniteTupleFunctions3| . ITFUN3) (|Infinity| . INFINITY) (|Integer| . INT) (|IntegerCombinatoricFunctions| . COMBINAT) (|IntegerLinearDependence| . ZLINDEP) (|IntegerNumberTheoryFunctions| . INTHEORY) (|IntegerPrimesPackage| . PRIMES) (|IntegerRetractions| . INTRET) (|IntegerRoots| . IROOT) (|IntegrationResultFunctions2| . IR2) (|IntegrationResultRFToFunction| . IRRF2F) (|IntegrationResultToFunction| . IR2F) (|Interval| . INTRVL) (|InventorDataSink| . IVDATA) (|InventorViewPort| . IVVIEW) (|InventorRenderPackage| . IVREND) (|InverseLaplaceTransform| . INVLAPLA) (|IrrRepSymNatPackage| . IRSN) (|KernelFunctions2| . KERNEL2) (|KeyedAccessFile| . KAFILE) (|LaplaceTransform| . LAPLACE) (|LazardMorenoSolvingPackage| . LAZM3PK) (|Library| . LIB) (|LieSquareMatrix| . LSQM) (|LinearOrdinaryDifferentialOperator| . LODO) (|LinearSystemMatrixPackage| . LSMP) (|LinearSystemMatrixPackage1| . LSMP1) (|LinearSystemPolynomialPackage| . LSPP) (|List| . LIST) (|ListFunctions2| . LIST2) (|ListFunctions3| . LIST3) (|ListToMap| . LIST2MAP) (|MakeFloatCompiledFunction| . MKFLCFN) (|MakeFunction| . MKFUNC) (|MakeRecord| . MKRECORD) (|MappingPackage1| . MAPPKG1) (|MappingPackage2| . MAPPKG2) (|MappingPackage3| . MAPPKG3) (|MappingPackage4| . MAPPKG4) (|MathMLFormat| . MMLFORM) (|Matrix| . MATRIX) (|MatrixCategoryFunctions2| . MATCAT2) (|MatrixCommonDenominator| . MCDEN) (|MatrixLinearAlgebraFunctions| . MATLIN) (|MergeThing| . MTHING) (|ModularDistinctDegreeFactorizer| . MDDFACT) (|ModuleOperator| . MODOP) (|MonoidRingFunctions2| . MRF2) (|MoreSystemCommands| . MSYSCMD) (|MPolyCatFunctions2| . MPC2) (|MPolyCatRationalFunctionFactorizer| . MPRFF) (|Multiset| . MSET) (|MultivariateFactorize| . MULTFACT) (|MultivariatePolynomial| . MPOLY) (|MultFiniteFactorize| . MFINFACT) (|MyUnivariatePolynomial| . MYUP) (|MyExpression| . MYEXPR) (|NoneFunctions1| . NONE1) (|NonNegativeInteger| . NNI) (|NottinghamGroup| . NOTTING) (|NormalizationPackage| . NORMPK) (|NormInMonogenicAlgebra| . NORMMA) (|NumberTheoreticPolynomialFunctions| . NTPOLFN) (|Numeric| . NUMERIC) (|NumericalOrdinaryDifferentialEquations| . NUMODE) (|NumericalQuadrature| . NUMQUAD) (|NumericComplexEigenPackage| . NCEP) (|NumericRealEigenPackage| . NREP) (|NumericContinuedFraction| . NCNTFRAC) (|Octonion| . OCT) (|OctonionCategoryFunctions2| . OCTCT2) (|OneDimensionalArray| . ARRAY1) (|OneDimensionalArrayFunctions2| . ARRAY12) (|OnePointCompletion| . ONECOMP) (|OnePointCompletionFunctions2| . ONECOMP2) (|OpenMathConnection| . OMCONN) (|OpenMathDevice| . OMDEV) (|OpenMathEncoding| . OMENC) (|OpenMathError| . OMERR) (|OpenMathErrorKind| . OMERRK) (|OpenMathPackage| . OMPKG) (|OpenMathServerPackage| . OMSERVER) (|OperationsQuery| . OPQUERY) (|OrderedCompletion| . ORDCOMP) (|OrderedCompletionFunctions2| . ORDCOMP2) (|OrdinaryDifferentialRing| . ODR) (|OrdSetInts| . OSI) (|OrthogonalPolynomialFunctions| . ORTHPOL) (|OutputPackage| . OUT) (|PadeApproximantPackage| . PADEPAC) (|Palette| . PALETTE) (|PartialFraction| . PFR) (|PatternFunctions2| . PATTERN2) (|ParametricPlaneCurve| . PARPCURV) (|ParametricSpaceCurve| . PARSCURV) (|ParametricSurface| . PARSURF) (|ParametricPlaneCurveFunctions2| . PARPC2) (|ParametricSpaceCurveFunctions2| . PARSC2) (|ParametricSurfaceFunctions2| . PARSU2) (|PartitionsAndPermutations| . PARTPERM) (|PatternMatch| . PATMATCH) (|PatternMatchAssertions| . PMASS) (|PatternMatchResultFunctions2| . PATRES2) (|PendantTree| . PENDTREE) (|Permanent| . PERMAN) (|PermutationGroupExamples| . PGE) (|PermutationGroup| . PERMGRP) (|Permutation| . PERM) (|Pi| . HACKPI) (|PiCoercions| . PICOERCE) (|PointFunctions2| . PTFUNC2) (|PolyGroebner| . PGROEB) (|Polynomial| . POLY) (|PolynomialAN2Expression| . PAN2EXPR) (|PolynomialComposition| . PCOMP) (|PolynomialDecomposition| . PDECOMP) (|PolynomialFunctions2| . POLY2) (|PolynomialIdeals| . IDEAL) (|PolynomialToUnivariatePolynomial| . POLY2UP) (|PositiveInteger| . PI) (|PowerSeriesLimitPackage| . LIMITPS) (|PrimeField| . PF) (|PrimitiveArrayFunctions2| . PRIMARR2) (|PrintPackage| . PRINT) (|QuadraticForm| . QFORM) (|QuasiComponentPackage| . QCMPACK) (|Quaternion| . QUAT) (|QuaternionCategoryFunctions2| . QUATCT2) (|QueryEquation| . QEQUAT) (|Queue| . QUEUE) (|QuotientFieldCategoryFunctions2| . QFCAT2) (|RadicalEigenPackage| . REP) (|RadicalSolvePackage| . SOLVERAD) (|RadixExpansion| . RADIX) (|RadixUtilities| . RADUTIL) (|RandomNumberSource| . RANDSRC) (|RationalFunction| . RF) (|RationalFunctionDefiniteIntegration| . DEFINTRF) (|RationalFunctionFactor| . RFFACT) (|RationalFunctionFactorizer| . RFFACTOR) (|RationalFunctionIntegration| . INTRF) (|RationalFunctionLimitPackage| . LIMITRF) (|RationalFunctionSign| . SIGNRF) (|RationalFunctionSum| . SUMRF) (|RationalRetractions| . RATRET) (|RealClosure| . RECLOS) (|RealPolynomialUtilitiesPackage| . POLUTIL) (|RealZeroPackage| . REAL0) (|RealZeroPackageQ| . REAL0Q) (|RecurrenceOperator| . RECOP) (|RectangularMatrixCategoryFunctions2| . RMCAT2) (|RegularSetDecompositionPackage| . RSDCMPK) (|RegularTriangularSet| . REGSET) (|RegularTriangularSetGcdPackage| . RSETGCD) (|RepresentationPackage1| . REP1) (|RepresentationPackage2| . REP2) (|ResolveLatticeCompletion| . RESLATC) (|RewriteRule| . RULE) (|RightOpenIntervalRootCharacterization| . ROIRC) (|RomanNumeral| . ROMAN) (|Ruleset| . RULESET) (|ScriptFormulaFormat| . FORMULA) (|ScriptFormulaFormat1| . FORMULA1) (|Segment| . SEG) (|SegmentBinding| . SEGBIND) (|SegmentBindingFunctions2| . SEGBIND2) (|SegmentFunctions2| . SEG2) (|Set| . SET) (|SimpleAlgebraicExtensionAlgFactor| . SAEFACT) (|SimplifyAlgebraicNumberConvertPackage| . SIMPAN) (|SingleInteger| . SINT) (|SmithNormalForm| . SMITH) (|SparseUnivariatePolynomialExpressions| . SUPEXPR) (|SparseUnivariatePolynomialFunctions2| . SUP2) (|SpecialOutputPackage| . SPECOUT) (|SquareFreeRegularSetDecompositionPackage| . SRDCMPK) (|SquareFreeRegularTriangularSet| . SREGSET) (|SquareFreeRegularTriangularSetGcdPackage| . SFRGCD) (|SquareFreeQuasiComponentPackage| . SFQCMPK) (|Stack| . STACK) (|Stream| . STREAM) (|StreamFunctions1| . STREAM1) (|StreamFunctions2| . STREAM2) (|StreamFunctions3| . STREAM3) (|String| . STRING) (|SturmHabichtPackage| . SHP) (|Symbol| . SYMBOL) (|SymmetricGroupCombinatoricFunctions| . SGCF) (|SystemSolvePackage| . SYSSOLP) (|SAERationalFunctionAlgFactor| . SAERFFC) (|Tableau| . TABLEAU) (|TaylorSeries| . TS) (|TaylorSolve| . UTSSOL) (|TexFormat| . TEX) (|TexFormat1| . TEX1) (|TextFile| . TEXTFILE) (|ThreeDimensionalViewport| . VIEW3D) (|ThreeSpace| . SPACE3) (|Timer| . TIMER) (|TopLevelDrawFunctions| . DRAW) (|TopLevelDrawFunctionsForAlgebraicCurves| . DRAWCURV) (|TopLevelDrawFunctionsForCompiledFunctions| . DRAWCFUN) (|TopLevelDrawFunctionsForPoints| . DRAWPT) (|TopLevelThreeSpace| . TOPSP) (|TranscendentalManipulations| . TRMANIP) (|TransSolvePackage| . SOLVETRA) (|Tree| . TREE) (|TrigonometricManipulations| . TRIGMNIP) (|UnivariateLaurentSeriesFunctions2| . ULS2) (|UnivariateFormalPowerSeries| . UFPS) (|UnivariateFormalPowerSeriesFunctions| . UFPS1) (|UnivariatePolynomial| . UP) (|UnivariatePolynomialCategoryFunctions2| . UPOLYC2) (|UnivariatePolynomialCommonDenominator| . UPCDEN) (|UnivariatePolynomialFunctions2| . UP2) (|UnivariatePolynomialMultiplicationPackage| . UPMP) (|UnivariatePuiseuxSeriesFunctions2| . UPXS2) (|UnivariateTaylorSeriesFunctions2| . UTS2) (|UniversalSegment| . UNISEG) (|UniversalSegmentFunctions2| . UNISEG2) (|UserDefinedVariableOrdering| . UDVO) (|Vector| . VECTOR) (|VectorFunctions2| . VECTOR2) (|ViewDefaultsPackage| . VIEWDEF) (|Void| . VOID) (|WuWenTsunTriangularSet| . WUTSET)) (|naglink| (|Asp1| . ASP1) (|Asp4| . ASP4) (|Asp6| . ASP6) (|Asp7| . ASP7) (|Asp8| . ASP8) (|Asp9| . ASP9) (|Asp10| . ASP10) (|Asp12| . ASP12) (|Asp19| . ASP19) (|Asp20| . ASP20) (|Asp24| . ASP24) (|Asp27| . ASP27) (|Asp28| . ASP28) (|Asp29| . ASP29) (|Asp30| . ASP30) (|Asp31| . ASP31) (|Asp33| . ASP33) (|Asp34| . ASP34) (|Asp35| . ASP35) (|Asp41| . ASP41) (|Asp42| . ASP42) (|Asp49| . ASP49) (|Asp50| . ASP50) (|Asp55| . ASP55) (|Asp73| . ASP73) (|Asp74| . ASP74) (|Asp77| . ASP77) (|Asp78| . ASP78) (|Asp80| . ASP80) (|FortranCode| . FC) (|FortranCodePackage1| . FCPAK1) (|FortranExpression| . FEXPR) (|FortranMachineTypeCategory| . FMTC) (|FortranMatrixCategory| . FMC) (|FortranMatrixFunctionCategory| . FMFUN) (|FortranOutputStackPackage| . FOP) (|FortranPackage| . FORT) (|FortranProgramCategory| . FORTCAT) (|FortranProgram| . FORTRAN) (|FortranFunctionCategory| . FORTFN) (|FortranScalarType| . FST) (|FortranType| . FT) (|FortranTemplate| . FTEM) (|FortranVectorFunctionCategory| . FVFUN) (|FortranVectorCategory| . FVC) (|MachineComplex| . MCMPLX) (|MachineFloat| . MFLOAT) (|MachineInteger| . MINT) (|MultiVariableCalculusFunctions| . MCALCFN) (|NagDiscreteFourierTransformInterfacePackage| . NAGDIS) (|NagEigenInterfacePackage| . NAGEIG) (|NAGLinkSupportPackage| . NAGSP) (|NagOptimisationInterfacePackage| . NAGOPT) (|NagQuadratureInterfacePackage| . NAGQUA) (|NagResultChecks| . NAGRES) (|NagSpecialFunctionsInterfacePackage| . NAGSPE) (|NagPolynomialRootsPackage| . NAGC02) (|NagRootFindingPackage| . NAGC05) (|NagSeriesSummationPackage| . NAGC06) (|NagIntegrationPackage| . NAGD01) (|NagOrdinaryDifferentialEquationsPackage| . NAGD02) (|NagPartialDifferentialEquationsPackage| . NAGD03) (|NagInterpolationPackage| . NAGE01) (|NagFittingPackage| . NAGE02) (|NagOptimisationPackage| . NAGE04) (|NagMatrixOperationsPackage| . NAGF01) (|NagEigenPackage| . NAGF02) (|NagLinearEquationSolvingPackage| . NAGF04) (|NagLapack| . NAGF07) (|NagSpecialFunctionsPackage| . NAGS) (|PackedHermitianSequence| . PACKED) (|Result| . RESULT) (|SimpleFortranProgram| . SFORT) (|Switch| . SWITCH) (|SymbolTable| . SYMTAB) (|TemplateUtilities| . TEMUTL) (|TheSymbolTable| . SYMS) (|ThreeDimensionalMatrix| . M3D)) (|anna| (|AnnaNumericalIntegrationPackage| . INTPACK) (|AnnaNumericalOptimizationPackage| . OPTPACK) (|AnnaOrdinaryDifferentialEquationPackage| . ODEPACK) (|AnnaPartialDifferentialEquationPackage| . PDEPACK) (|AttributeButtons| . ATTRBUT) (|BasicFunctions| . BFUNCT) (|d01ajfAnnaType| . D01AJFA) (|d01akfAnnaType| . D01AKFA) (|d01alfAnnaType| . D01ALFA) (|d01amfAnnaType| . D01AMFA) (|d01anfAnnaType| . D01ANFA) (|d01apfAnnaType| . D01APFA) (|d01aqfAnnaType| . D01AQFA) (|d01asfAnnaType| . D01ASFA) (|d01fcfAnnaType| . D01FCFA) (|d01gbfAnnaType| . D01GBFA) (|d01AgentsPackage| . D01AGNT) (|d01TransformFunctionType| . D01TRNS) (|d01WeightsPackage| . D01WGTS) (|d02AgentsPackage| . D02AGNT) (|d02bbfAnnaType| . D02BBFA) (|d02bhfAnnaType| . D02BHFA) (|d02cjfAnnaType| . D02CJFA) (|d02ejfAnnaType| . D02EJFA) (|d03AgentsPackage| . D03AGNT) (|d03eefAnnaType| . D03EEFA) (|d03fafAnnaType| . D03FAFA) (|e04AgentsPackage| . E04AGNT) (|e04dgfAnnaType| . E04DGFA) (|e04fdfAnnaType| . E04FDFA) (|e04gcfAnnaType| . E04GCFA) (|e04jafAnnaType| . E04JAFA) (|e04mbfAnnaType| . E04MBFA) (|e04nafAnnaType| . E04NAFA) (|e04ucfAnnaType| . E04UCFA) (|ExpertSystemContinuityPackage| . ESCONT) (|ExpertSystemContinuityPackage1| . ESCONT1) (|ExpertSystemToolsPackage| . ESTOOLS) (|ExpertSystemToolsPackage1| . ESTOOLS1) (|ExpertSystemToolsPackage2| . ESTOOLS2) (|NumericalIntegrationCategory| . NUMINT) (|NumericalIntegrationProblem| . NIPROB) (|NumericalODEProblem| . ODEPROB) (|NumericalOptimizationCategory| . OPTCAT) (|NumericalOptimizationProblem| . OPTPROB) (|NumericalPDEProblem| . PDEPROB) (|ODEIntensityFunctionsTable| . ODEIFTBL) (|IntegrationFunctionsTable| . INTFTBL) (|OrdinaryDifferentialEquationsSolverCategory| . ODECAT) (|PartialDifferentialEquationsSolverCategory| . PDECAT) (|RoutinesTable| . ROUTINE)) (|categories| (|AbelianGroup| . ABELGRP) (|AbelianMonoid| . ABELMON) (|AbelianMonoidRing| . AMR) (|AbelianSemiGroup| . ABELSG) (|Aggregate| . AGG) (|Algebra| . ALGEBRA) (|AlgebraicallyClosedField| . ACF) (|AlgebraicallyClosedFunctionSpace| . ACFS) (|ArcHyperbolicFunctionCategory| . AHYP) (|ArcTrigonometricFunctionCategory| . ATRIG) (|AssociationListAggregate| . ALAGG) (|AttributeRegistry| . ATTREG) (|BagAggregate| . BGAGG) (|BasicType| . BASTYPE) (|BiModule| . BMODULE) (|BinaryRecursiveAggregate| . BRAGG) (|BinaryTreeCategory| . BTCAT) (|BitAggregate| . BTAGG) (|CachableSet| . CACHSET) (|CancellationAbelianMonoid| . CABMON) (|CharacteristicNonZero| . CHARNZ) (|CharacteristicZero| . CHARZ) (|CoercibleTo| . KOERCE) (|Collection| . CLAGG) (|CombinatorialFunctionCategory| . CFCAT) (|CombinatorialOpsCategory| . COMBOPC) (|CommutativeRing| . COMRING) (|ComplexCategory| . COMPCAT) (|ConvertibleTo| . KONVERT) (|DequeueAggregate| . DQAGG) (|Dictionary| . DIAGG) (|DictionaryOperations| . DIOPS) (|DifferentialExtension| . DIFEXT) (|DifferentialPolynomialCategory| . DPOLCAT) (|DifferentialRing| . DIFRING) (|DifferentialVariableCategory| . DVARCAT) (|DirectProductCategory| . DIRPCAT) (|DivisionRing| . DIVRING) (|DoublyLinkedAggregate| . DLAGG) (|ElementaryFunctionCategory| . ELEMFUN) (|Eltable| . ELTAB) (|EltableAggregate| . ELTAGG) (|EntireRing| . ENTIRER) (|EuclideanDomain| . EUCDOM) (|Evalable| . EVALAB) (|ExpressionSpace| . ES) (|ExtensibleLinearAggregate| . ELAGG) (|ExtensionField| . XF) (|Field| . FIELD) (|FieldOfPrimeCharacteristic| . FPC) (|Finite| . FINITE) (|FileCategory| . FILECAT) (|FileNameCategory| . FNCAT) (|FiniteAbelianMonoidRing| . FAMR) (|FiniteAlgebraicExtensionField| . FAXF) (|FiniteDivisorCategory| . FDIVCAT) (|FiniteFieldCategory| . FFIELDC) (|FiniteLinearAggregate| . FLAGG) (|FiniteRankNonAssociativeAlgebra| . FINAALG) (|FiniteRankAlgebra| . FINRALG) (|FiniteSetAggregate| . FSAGG) (|FloatingPointSystem| . FPS) (|FramedAlgebra| . FRAMALG) (|FramedNonAssociativeAlgebra| . FRNAALG) (|FramedNonAssociativeAlgebraFunctions2| . FRNAAF2) (|FreeAbelianMonoidCategory| . FAMONC) (|FreeLieAlgebra| . FLALG) (|FreeModuleCat| . FMCAT) (|FullyEvalableOver| . FEVALAB) (|FullyLinearlyExplicitRingOver| . FLINEXP) (|FullyPatternMatchable| . FPATMAB) (|FullyRetractableTo| . FRETRCT) (|FunctionFieldCategory| . FFCAT) (|FunctionSpace| . FS) (|GcdDomain| . GCDDOM) (|GradedAlgebra| . GRALG) (|GradedModule| . GRMOD) (|Group| . GROUP) (|HomogeneousAggregate| . HOAGG) (|HyperbolicFunctionCategory| . HYPCAT) (|IndexedAggregate| . IXAGG) (|IndexedDirectProductCategory| . IDPC) (|InnerEvalable| . IEVALAB) (|IntegerNumberSystem| . INS) (|IntegralDomain| . INTDOM) (|IntervalCategory| . INTCAT) (|KeyedDictionary| . KDAGG) (|LazyStreamAggregate| . LZSTAGG) (|LeftAlgebra| . LALG) (|LeftModule| . LMODULE) (|LieAlgebra| . LIECAT) (|LinearAggregate| . LNAGG) (|LinearlyExplicitRingOver| . LINEXP) (|LinearOrdinaryDifferentialOperatorCategory| . LODOCAT) (|LiouvillianFunctionCategory| . LFCAT) (|ListAggregate| . LSAGG) (|Logic| . LOGIC) (|MatrixCategory| . MATCAT) (|Module| . MODULE) (|Monad| . MONAD) (|MonadWithUnit| . MONADWU) (|Monoid| . MONOID) (|MonogenicAlgebra| . MONOGEN) (|MonogenicLinearOperator| . MLO) (|MultiDictionary| . MDAGG) (|MultisetAggregate| . MSETAGG) (|MultivariateTaylorSeriesCategory| . MTSCAT) (|NonAssociativeAlgebra| . NAALG) (|NonAssociativeRing| . NASRING) (|NonAssociativeRng| . NARNG) (|NormalizedTriangularSetCategory| . NTSCAT) (|Object| . OBJECT) (|OctonionCategory| . OC) (|OneDimensionalArrayAggregate| . A1AGG) (|OpenMath| . OM) (|OrderedAbelianGroup| . OAGROUP) (|OrderedAbelianMonoid| . OAMON) (|OrderedAbelianMonoidSup| . OAMONS) (|OrderedAbelianSemiGroup| . OASGP) (|OrderedCancellationAbelianMonoid| . OCAMON) (|OrderedFinite| . ORDFIN) (|OrderedIntegralDomain| . OINTDOM) (|OrderedMonoid| . ORDMON) (|OrderedMultisetAggregate| . OMSAGG) (|OrderedRing| . ORDRING) (|OrderedSet| . ORDSET) (|PAdicIntegerCategory| . PADICCT) (|PartialDifferentialRing| . PDRING) (|PartialTranscendentalFunctions| . PTRANFN) (|Patternable| . PATAB) (|PatternMatchable| . PATMAB) (|PermutationCategory| . PERMCAT) (|PlottablePlaneCurveCategory| . PPCURVE) (|PlottableSpaceCurveCategory| . PSCURVE) (|PointCategory| . PTCAT) (|PolynomialCategory| . POLYCAT) (|PolynomialFactorizationExplicit| . PFECAT) (|PolynomialSetCategory| . PSETCAT) (|PowerSeriesCategory| . PSCAT) (|PrimitiveFunctionCategory| . PRIMCAT) (|PrincipalIdealDomain| . PID) (|PriorityQueueAggregate| . PRQAGG) (|QuaternionCategory| . QUATCAT) (|QueueAggregate| . QUAGG) (|QuotientFieldCategory| . QFCAT) (|RadicalCategory| . RADCAT) (|RealClosedField| . RCFIELD) (|RealConstant| . REAL) (|RealNumberSystem| . RNS) (|RealRootCharacterizationCategory| . RRCC) (|RectangularMatrixCategory| . RMATCAT) (|RecursiveAggregate| . RCAGG) (|RecursivePolynomialCategory| . RPOLCAT) (|RegularChain| . RGCHAIN) (|RegularTriangularSetCategory| . RSETCAT) (|RetractableTo| . RETRACT) (|RightModule| . RMODULE) (|Ring| . RING) (|Rng| . RNG) (|SegmentCategory| . SEGCAT) (|SegmentExpansionCategory| . SEGXCAT) (|SemiGroup| . SGROUP) (|SetAggregate| . SETAGG) (|SetCategory| . SETCAT) (|SExpressionCategory| . SEXCAT) (|SpecialFunctionCategory| . SPFCAT) (|SquareFreeNormalizedTriangularSetCategory| . SNTSCAT) (|SquareFreeRegularTriangularSetCategory| . SFRTCAT) (|SquareMatrixCategory| . SMATCAT) (|StackAggregate| . SKAGG) (|StepThrough| . STEP) (|StreamAggregate| . STAGG) (|StringAggregate| . SRAGG) (|StringCategory| . STRICAT) (|StructuralConstantsPackage| . SCPKG) (|TableAggregate| . TBAGG) (|ThreeSpaceCategory| . SPACEC) (|TranscendentalFunctionCategory| . TRANFUN) (|TriangularSetCategory| . TSETCAT) (|TrigonometricFunctionCategory| . TRIGCAT) (|TwoDimensionalArrayCategory| . ARR2CAT) (|Type| . TYPE) (|UnaryRecursiveAggregate| . URAGG) (|UniqueFactorizationDomain| . UFD) (|UnivariateLaurentSeriesCategory| . ULSCAT) (|UnivariateLaurentSeriesConstructorCategory| . ULSCCAT) (|UnivariatePolynomialCategory| . UPOLYC) (|UnivariatePowerSeriesCategory| . UPSCAT) (|UnivariatePuiseuxSeriesCategory| . UPXSCAT) (|UnivariatePuiseuxSeriesConstructorCategory| . UPXSCCA) (|UnivariateSkewPolynomialCategory| . OREPCAT) (|UnivariateTaylorSeriesCategory| . UTSCAT) (|VectorCategory| . VECTCAT) (|VectorSpace| . VSPACE) (|XAlgebra| . XALG) (|XFreeAlgebra| . XFALG) (|XPolynomialsCat| . XPOLYC) (|ZeroDimensionalSolvePackage| . ZDSOLVE)) (|Hidden| (|AlgebraicFunction| . AF) (|AlgebraicFunctionField| . ALGFF) (|AlgebraicHermiteIntegration| . INTHERAL) (|AlgebraicIntegrate| . INTALG) (|AlgebraicIntegration| . INTAF) (|AnonymousFunction| . ANON) (|AntiSymm| . ANTISYM) (|ApplyRules| . APPRULE) (|ApplyUnivariateSkewPolynomial| . APPLYORE) (|ArrayStack| . ASTACK) (|AssociatedEquations| . ASSOCEQ) (|AssociationList| . ALIST) (|Automorphism| . AUTOMOR) (|BalancedFactorisation| . BALFACT) (|BalancedPAdicInteger| . BPADIC) (|BalancedPAdicRational| . BPADICRT) (|BezoutMatrix| . BEZOUT) (|BoundIntegerRoots| . BOUNDZRO) (|BrillhartTests| . BRILL) (|ChangeOfVariable| . CHVAR) (|CharacteristicPolynomialInMonogenicalAlgebra| . CPIMA) (|ChineseRemainderToolsForIntegralBases| . IBACHIN) (|CoerceVectorMatrixPackage| . CVMP) (|CombinatorialFunction| . COMBF) (|CommonOperators| . COMMONOP) (|CommuteUnivariatePolynomialCategory| . COMMUPC) (|ComplexIntegerSolveLinearPolynomialEquation| . CINTSLPE) (|ComplexPattern| . COMPLPAT) (|ComplexPatternMatch| . CPMATCH) (|ComplexRootFindingPackage| . CRFP) (|ConstantLODE| . ODECONST) (|CyclicStreamTools| . CSTTOOLS) (|CyclotomicPolynomialPackage| . CYCLOTOM) (|DefiniteIntegrationTools| . DFINTTLS) (|DegreeReductionPackage| . DEGRED) (|DeRhamComplex| . DERHAM) (|DifferentialSparseMultivariatePolynomial| . DSMP) (|DirectProduct| . DIRPROD) (|DirectProductMatrixModule| . DPMM) (|DirectProductModule| . DPMO) (|DiscreteLogarithmPackage| . DLP) (|DistributedMultivariatePolynomial| . DMP) (|DoubleResultantPackage| . DBLRESP) (|DrawOptionFunctions0| . DROPT0) (|DrawOptionFunctions1| . DROPT1) (|ElementaryFunction| . EF) (|ElementaryFunctionsUnivariateLaurentSeries| . EFULS) (|ElementaryFunctionsUnivariatePuiseuxSeries| . EFUPXS) (|ElementaryIntegration| . INTEF) (|ElementaryRischDE| . RDEEF) (|ElementaryRischDESystem| . RDEEFS) (|EllipticFunctionsUnivariateTaylorSeries| . ELFUTS) (|EqTable| . EQTBL) (|EuclideanModularRing| . EMR) (|EvaluateCycleIndicators| . EVALCYC) (|ExponentialExpansion| . EXPEXPAN) (|ExponentialOfUnivariatePuiseuxSeries| . EXPUPXS) (|ExpressionSpaceFunctions1| . ES1) (|ExpressionTubePlot| . EXPRTUBE) (|ExtAlgBasis| . EAB) (|FactoredFunctions| . FACTFUNC) (|FactoredFunctionUtilities| . FRUTIL) (|FactoringUtilities| . FACUTIL) (|FGLMIfCanPackage| . FGLMICPK) (|FindOrderFinite| . FORDER) (|FiniteDivisor| . FDIV) (|FiniteFieldCyclicGroupExtension| . FFCGX) (|FiniteFieldCyclicGroupExtensionByPolynomial| . FFCGP) (|FiniteFieldExtension| . FFX) (|FiniteFieldExtensionByPolynomial| . FFP) (|FiniteFieldFunctions| . FFF) (|FiniteFieldNormalBasisExtension| . FFNBX) (|FiniteFieldNormalBasisExtensionByPolynomial| . FFNBP) (|FiniteFieldPolynomialPackage| . FFPOLY) (|FiniteFieldSolveLinearPolynomialEquation| . FFSLPE) (|FormalFraction| . FORMAL) (|FourierComponent| . FCOMP) (|FractionalIdeal| . FRIDEAL) (|FramedModule| . FRMOD) (|FreeAbelianGroup| . FAGROUP) (|FreeAbelianMonoid| . FAMONOID) (|FreeGroup| . FGROUP) (|FreeModule| . FM) (|FreeModule1| . FM1) (|FreeMonoid| . FMONOID) (|FunctionalSpecialFunction| . FSPECF) (|FunctionCalled| . FUNCTION) (|FunctionFieldIntegralBasis| . FFINTBAS) (|FunctionSpaceReduce| . FSRED) (|FunctionSpaceToUnivariatePowerSeries| . FS2UPS) (|FunctionSpaceToExponentialExpansion| . FS2EXPXP) (|FunctionSpaceUnivariatePolynomialFactor| . FSUPFACT) (|GaloisGroupFactorizationUtilities| . GALFACTU) (|GaloisGroupFactorizer| . GALFACT) (|GaloisGroupPolynomialUtilities| . GALPOLYU) (|GaloisGroupUtilities| . GALUTIL) (|GeneralHenselPackage| . GHENSEL) (|GeneralDistributedMultivariatePolynomial| . GDMP) (|GeneralPolynomialGcdPackage| . GENPGCD) (|GeneralSparseTable| . GSTBL) (|GenericNonAssociativeAlgebra| . GCNAALG) (|GenExEuclid| . GENEEZ) (|GeneralizedMultivariateFactorize| . GENMFACT) (|GeneralModulePolynomial| . GMODPOL) (|GeneralPolynomialSet| . GPOLSET) (|GeneralTriangularSet| . GTSET) (|GenUFactorize| . GENUFACT) (|GenusZeroIntegration| . INTG0) (|GosperSummationMethod| . GOSPER) (|GraphImage| . GRIMAGE) (|GrayCode| . GRAY) (|GroebnerInternalPackage| . GBINTERN) (|GroebnerSolve| . GROEBSOL) (|HashTable| . HASHTBL) (|Heap| . HEAP) (|HeuGcd| . HEUGCD) (|HomogeneousDistributedMultivariatePolynomial| . HDMP) (|HyperellipticFiniteDivisor| . HELLFDIV) (|IncrementingMaps| . INCRMAPS) (|IndexedBits| . IBITS) (|IndexedDirectProductAbelianGroup| . IDPAG) (|IndexedDirectProductAbelianMonoid| . IDPAM) (|IndexedDirectProductObject| . IDPO) (|IndexedDirectProductOrderedAbelianMonoid| . IDPOAM) (|IndexedDirectProductOrderedAbelianMonoidSup| . IDPOAMS) (|IndexedExponents| . INDE) (|IndexedFlexibleArray| . IFARRAY) (|IndexedList| . ILIST) (|IndexedMatrix| . IMATRIX) (|IndexedOneDimensionalArray| . IARRAY1) (|IndexedString| . ISTRING) (|IndexedTwoDimensionalArray| . IARRAY2) (|IndexedVector| . IVECTOR) (|InnerAlgFactor| . IALGFACT) (|InnerAlgebraicNumber| . IAN) (|InnerCommonDenominator| . ICDEN) (|InnerFiniteField| . IFF) (|InnerFreeAbelianMonoid| . IFAMON) (|InnerIndexedTwoDimensionalArray| . IIARRAY2) (|InnerMatrixLinearAlgebraFunctions| . IMATLIN) (|InnerMatrixQuotientFieldFunctions| . IMATQF) (|InnerModularGcd| . INMODGCD) (|InnerMultFact| . INNMFACT) (|InnerNormalBasisFieldFunctions| . INBFF) (|InnerNumericEigenPackage| . INEP) (|InnerNumericFloatSolvePackage| . INFSP) (|InnerPAdicInteger| . IPADIC) (|InnerPolySign| . INPSIGN) (|InnerPolySum| . ISUMP) (|InnerPrimeField| . IPF) (|InnerSparseUnivariatePowerSeries| . ISUPS) (|InnerTable| . INTABL) (|InnerTaylorSeries| . ITAYLOR) (|InnerTrigonometricManipulations| . ITRIGMNP) (|InputForm| . INFORM) (|InputFormFunctions1| . INFORM1) (|IntegerBits| . INTBIT) (|IntegerFactorizationPackage| . INTFACT) (|IntegerMod| . ZMOD) (|IntegerSolveLinearPolynomialEquation| . INTSLPE) (|IntegralBasisPolynomialTools| . IBPTOOLS) (|IntegralBasisTools| . IBATOOL) (|IntegrationResult| . IR) (|IntegrationTools| . INTTOOLS) (|InternalPrintPackage| . IPRNTPK) (|InternalRationalUnivariateRepresentationPackage| . IRURPK) (|IrredPolyOverFiniteField| . IRREDFFX) (|Kernel| . KERNEL) (|Kovacic| . KOVACIC) (|LaurentPolynomial| . LAUPOL) (|LeadingCoefDetermination| . LEADCDET) (|LexTriangularPackage| . LEXTRIPK) (|LieExponentials| . LEXP) (|LiePolynomial| . LPOLY) (|LinearDependence| . LINDEP) (|LinearOrdinaryDifferentialOperatorFactorizer| . LODOF) (|LinearOrdinaryDifferentialOperator1| . LODO1) (|LinearOrdinaryDifferentialOperator2| . LODO2) (|LinearOrdinaryDifferentialOperatorsOps| . LODOOPS) (|LinearPolynomialEquationByFractions| . LPEFRAC) (|LinGroebnerPackage| . LGROBP) (|LiouvillianFunction| . LF) (|ListMonoidOps| . LMOPS) (|ListMultiDictionary| . LMDICT) (|LocalAlgebra| . LA) (|Localize| . LO) (|LyndonWord| . LWORD) (|Magma| . MAGMA) (|MakeBinaryCompiledFunction| . MKBCFUNC) (|MakeCachableSet| . MKCHSET) (|MakeUnaryCompiledFunction| . MKUCFUNC) (|MappingPackageInternalHacks1| . MAPHACK1) (|MappingPackageInternalHacks2| . MAPHACK2) (|MappingPackageInternalHacks3| . MAPHACK3) (|MeshCreationRoutinesForThreeDimensions| . MESH) (|ModMonic| . MODMON) (|ModularField| . MODFIELD) (|ModularHermitianRowReduction| . MHROWRED) (|ModularRing| . MODRING) (|ModuleMonomial| . MODMONOM) (|MoebiusTransform| . MOEBIUS) (|MonoidRing| . MRING) (|MonomialExtensionTools| . MONOTOOL) (|MPolyCatPolyFactorizer| . MPCPF) (|MPolyCatFunctions3| . MPC3) (|MRationalFactorize| . MRATFAC) (|MultipleMap| . MMAP) (|MultivariateLifting| . MLIFT) (|MultivariateSquareFree| . MULTSQFR) (|HomogeneousDirectProduct| . HDP) (|NewSparseMultivariatePolynomial| . NSMP) (|NewSparseUnivariatePolynomial| . NSUP) (|NewSparseUnivariatePolynomialFunctions2| . NSUP2) (|NonCommutativeOperatorDivision| . NCODIV) (|NewtonInterpolation| . NEWTON) (|None| . NONE) (|NonLinearFirstOrderODESolver| . NODE1) (|NonLinearSolvePackage| . NLINSOL) (|NormRetractPackage| . NORMRETR) (|NPCoef| . NPCOEF) (|NumberFormats| . NUMFMT) (|NumberFieldIntegralBasis| . NFINTBAS) (|NumericTubePlot| . NUMTUBE) (|ODEIntegration| . ODEINT) (|ODETools| . ODETOOLS) (|Operator| . OP) (|OppositeMonogenicLinearOperator| . OMLO) (|OrderedDirectProduct| . ODP) (|OrderedFreeMonoid| . OFMONOID) (|OrderedVariableList| . OVAR) (|OrderingFunctions| . ORDFUNS) (|OrderlyDifferentialPolynomial| . ODPOL) (|OrderlyDifferentialVariable| . ODVAR) (|OrdinaryWeightedPolynomials| . OWP) (|OutputForm| . OUTFORM) (|PadeApproximants| . PADE) (|PAdicInteger| . PADIC) (|PAdicRational| . PADICRAT) (|PAdicRationalConstructor| . PADICRC) (|PAdicWildFunctionFieldIntegralBasis| . PWFFINTB) (|ParadoxicalCombinatorsForStreams| . YSTREAM) (|ParametricLinearEquations| . PLEQN) (|PartialFractionPackage| . PFRPAC) (|Partition| . PRTITION) (|Pattern| . PATTERN) (|PatternFunctions1| . PATTERN1) (|PatternMatchFunctionSpace| . PMFS) (|PatternMatchIntegerNumberSystem| . PMINS) (|PatternMatchIntegration| . INTPM) (|PatternMatchKernel| . PMKERNEL) (|PatternMatchListAggregate| . PMLSAGG) (|PatternMatchListResult| . PATLRES) (|PatternMatchPolynomialCategory| . PMPLCAT) (|PatternMatchPushDown| . PMDOWN) (|PatternMatchQuotientFieldCategory| . PMQFCAT) (|PatternMatchResult| . PATRES) (|PatternMatchSymbol| . PMSYM) (|PatternMatchTools| . PMTOOLS) (|PlaneAlgebraicCurvePlot| . ACPLOT) (|Plot| . PLOT) (|PlotFunctions1| . PLOT1) (|PlotTools| . PLOTTOOL) (|Plot3D| . PLOT3D) (|PoincareBirkhoffWittLyndonBasis| . PBWLB) (|Point| . POINT) (|PointsOfFiniteOrder| . PFO) (|PointsOfFiniteOrderRational| . PFOQ) (|PointsOfFiniteOrderTools| . PFOTOOLS) (|PointPackage| . PTPACK) (|PolToPol| . POLTOPOL) (|PolynomialCategoryLifting| . POLYLIFT) (|PolynomialCategoryQuotientFunctions| . POLYCATQ) (|PolynomialFactorizationByRecursion| . PFBR) (|PolynomialFactorizationByRecursionUnivariate| . PFBRU) (|PolynomialGcdPackage| . PGCD) (|PolynomialInterpolation| . PINTERP) (|PolynomialInterpolationAlgorithms| . PINTERPA) (|PolynomialNumberTheoryFunctions| . PNTHEORY) (|PolynomialRing| . PR) (|PolynomialRoots| . POLYROOT) (|PolynomialSetUtilitiesPackage| . PSETPK) (|PolynomialSolveByFormulas| . SOLVEFOR) (|PolynomialSquareFree| . PSQFR) (|PrecomputedAssociatedEquations| . PREASSOC) (|PrimitiveArray| . PRIMARR) (|PrimitiveElement| . PRIMELT) (|PrimitiveRatDE| . ODEPRIM) (|PrimitiveRatRicDE| . ODEPRRIC) (|Product| . PRODUCT) (|PseudoRemainderSequence| . PRS) (|PseudoLinearNormalForm| . PSEUDLIN) (|PureAlgebraicIntegration| . INTPAF) (|PureAlgebraicLODE| . ODEPAL) (|PushVariables| . PUSHVAR) (|QuasiAlgebraicSet| . QALGSET) (|QuasiAlgebraicSet2| . QALGSET2) (|RadicalFunctionField| . RADFF) (|RandomDistributions| . RDIST) (|RandomFloatDistributions| . RFDIST) (|RandomIntegerDistributions| . RIDIST) (|RationalFactorize| . RATFACT) (|RationalIntegration| . INTRAT) (|RationalInterpolation| . RINTERP) (|RationalLODE| . ODERAT) (|RationalRicDE| . ODERTRIC) (|RationalUnivariateRepresentationPackage| . RURPK) (|RealSolvePackage| . REALSOLV) (|RectangularMatrix| . RMATRIX) (|ReducedDivisor| . RDIV) (|ReduceLODE| . ODERED) (|ReductionOfOrder| . REDORDER) (|Reference| . REF) (|RepeatedDoubling| . REPDB) (|RepeatedSquaring| . REPSQ) (|ResidueRing| . RESRING) (|RetractSolvePackage| . RETSOL) (|RuleCalled| . RULECOLD) (|SetOfMIntegersInOneToN| . SETMN) (|SExpression| . SEX) (|SExpressionOf| . SEXOF) (|SequentialDifferentialPolynomial| . SDPOL) (|SequentialDifferentialVariable| . SDVAR) (|SimpleAlgebraicExtension| . SAE) (|SingletonAsOrderedSet| . SAOS) (|SortedCache| . SCACHE) (|SortPackage| . SORTPAK) (|SparseMultivariatePolynomial| . SMP) (|SparseMultivariateTaylorSeries| . SMTS) (|SparseTable| . STBL) (|SparseUnivariatePolynomial| . SUP) (|SparseUnivariateSkewPolynomial| . ORESUP) (|SparseUnivariateLaurentSeries| . SULS) (|SparseUnivariatePuiseuxSeries| . SUPXS) (|SparseUnivariateTaylorSeries| . SUTS) (|SplitHomogeneousDirectProduct| . SHDP) (|SplittingNode| . SPLNODE) (|SplittingTree| . SPLTREE) (|SquareMatrix| . SQMATRIX) (|Stack| . STACK) (|StorageEfficientMatrixOperations| . MATSTOR) (|StreamInfiniteProduct| . STINPROD) (|StreamTaylorSeriesOperations| . STTAYLOR) (|StreamTranscendentalFunctions| . STTF) (|StreamTranscendentalFunctionsNonCommutative| . STTFNC) (|StringTable| . STRTBL) (|SubResultantPackage| . SUBRESP) (|SubSpace| . SUBSPACE) (|SubSpaceComponentProperty| . COMPPROP) (|SuchThat| . SUCH) (|SupFractionFactorizer| . SUPFRACF) (|SymmetricFunctions| . SYMFUNC) (|SymmetricPolynomial| . SYMPOLY) (|SystemODESolver| . ODESYS) (|Table| . TABLE) (|TableauxBumpers| . TABLBUMP) (|TabulatedComputationPackage| . TBCMPPK) (|TangentExpansions| . TANEXP) (|ToolsForSign| . TOOLSIGN) (|TranscendentalHermiteIntegration| . INTHERTR) (|TranscendentalIntegration| . INTTR) (|TranscendentalRischDE| . RDETR) (|TranscendentalRischDESystem| . RDETRS) (|TransSolvePackageService| . SOLVESER) (|TriangularMatrixOperations| . TRIMAT) (|TubePlot| . TUBE) (|TubePlotTools| . TUBETOOL) (|Tuple| . TUPLE) (|TwoDimensionalArray| . ARRAY2) (|TwoDimensionalPlotClipping| . CLIP) (|TwoDimensionalViewport| . VIEW2D) (|TwoFactorize| . TWOFACT) (|UnivariateFactorize| . UNIFACT) (|UnivariateLaurentSeries| . ULS) (|UnivariateLaurentSeriesConstructor| . ULSCONS) (|UnivariatePolynomialDecompositionPackage| . UPDECOMP) (|UnivariatePolynomialDivisionPackage| . UPDIVP) (|UnivariatePolynomialSquareFree| . UPSQFREE) (|UnivariatePuiseuxSeries| . UPXS) (|UnivariatePuiseuxSeriesConstructor| . UPXSCONS) (|UnivariatePuiseuxSeriesWithExponentialSingularity| . UPXSSING) (|UnivariateSkewPolynomial| . OREUP) (|UnivariateSkewPolynomialCategoryOps| . OREPCTO) (|UnivariateTaylorSeries| . UTS) (|UnivariateTaylorSeriesODESolver| . UTSODE) (|UserDefinedPartialOrdering| . UDPO) (|UTSodetools| . UTSODETL) (|Variable| . VARIABLE) (|ViewportPackage| . VIEW) (|WeierstrassPreparation| . WEIER) (|WeightedPolynomials| . WP) (|WildFunctionFieldIntegralBasis| . WFFINTBS) (|XDistributedPolynomial| . XDPOLY) (|XExponentialPackage| . XEXPPKG) (|XPBWPolynomial| . XPBWPOLY) (|XPolynomial| . XPOLY) (|XPolynomialRing| . XPR) (|XRecursivePolynomial| . XRPOLY)) (|defaults| (|AbelianGroup&| . ABELGRP-) (|AbelianMonoid&| . ABELMON-) (|AbelianMonoidRing&| . AMR-) (|AbelianSemiGroup&| . ABELSG-) (|Aggregate&| . AGG-) (|Algebra&| . ALGEBRA-) (|AlgebraicallyClosedField&| . ACF-) (|AlgebraicallyClosedFunctionSpace&| . ACFS-) (|ArcTrigonometricFunctionCategory&| . ATRIG-) (|BagAggregate&| . BGAGG-) (|BasicType&| . BASTYPE-) (|BinaryRecursiveAggregate&| . BRAGG-) (|BinaryTreeCategory&| . BTCAT-) (|BitAggregate&| . BTAGG-) (|Collection&| . CLAGG-) (|ComplexCategory&| . COMPCAT-) (|Dictionary&| . DIAGG-) (|DictionaryOperations&| . DIOPS-) (|DifferentialExtension&| . DIFEXT-) (|DifferentialPolynomialCategory&| . DPOLCAT-) (|DifferentialRing&| . DIFRING-) (|DifferentialVariableCategory&| . DVARCAT-) (|DirectProductCategory&| . DIRPCAT-) (|DivisionRing&| . DIVRING-) (|ElementaryFunctionCategory&| . ELEMFUN-) (|EltableAggregate&| . ELTAGG-) (|EuclideanDomain&| . EUCDOM-) (|Evalable&| . EVALAB-) (|ExpressionSpace&| . ES-) (|ExtensibleLinearAggregate&| . ELAGG-) (|ExtensionField&| . XF-) (|Field&| . FIELD-) (|FieldOfPrimeCharacteristic&| . FPC-) (|FiniteAbelianMonoidRing&| . FAMR-) (|FiniteAlgebraicExtensionField&| . FAXF-) (|FiniteDivisorCategory&| . FDIVCAT-) (|FiniteFieldCategory&| . FFIELDC-) (|FiniteLinearAggregate&| . FLAGG-) (|FiniteSetAggregate&| . FSAGG-) (|FiniteRankAlgebra&| . FINRALG-) (|FiniteRankNonAssociativeAlgebra&| . FINAALG-) (|FloatingPointSystem&| . FPS-) (|FramedAlgebra&| . FRAMALG-) (|FramedNonAssociativeAlgebra&| . FRNAALG-) (|FullyEvalableOver&| . FEVALAB-) (|FullyLinearlyExplicitRingOver&| . FLINEXP-) (|FullyRetractableTo&| . FRETRCT-) (|FunctionFieldCategory&| . FFCAT-) (|FunctionSpace&| . FS-) (|GcdDomain&| . GCDDOM-) (|GradedAlgebra&| . GRALG-) (|GradedModule&| . GRMOD-) (|Group&| . GROUP-) (|HomogeneousAggregate&| . HOAGG-) (|HyperbolicFunctionCategory&| . HYPCAT-) (|IndexedAggregate&| . IXAGG-) (|InnerEvalable&| . IEVALAB-) (|IntegerNumberSystem&| . INS-) (|IntegralDomain&| . INTDOM-) (|KeyedDictionary&| . KDAGG-) (|LazyStreamAggregate&| . LZSTAGG-) (|LeftAlgebra&| . LALG-) (|LieAlgebra&| . LIECAT-) (|LinearAggregate&| . LNAGG-) (|ListAggregate&| . LSAGG-) (|Logic&| . LOGIC-) (|LinearOrdinaryDifferentialOperatorCategory&| . LODOCAT-) (|MatrixCategory&| . MATCAT-) (|Module&| . MODULE-) (|Monad&| . MONAD-) (|MonadWithUnit&| . MONADWU-) (|Monoid&| . MONOID-) (|MonogenicAlgebra&| . MONOGEN-) (|NonAssociativeAlgebra&| . NAALG-) (|NonAssociativeRing&| . NASRING-) (|NonAssociativeRng&| . NARNG-) (|OctonionCategory&| . OC-) (|OneDimensionalArrayAggregate&| . A1AGG-) (|OrderedRing&| . ORDRING-) (|OrderedSet&| . ORDSET-) (|PartialDifferentialRing&| . PDRING-) (|PolynomialCategory&| . POLYCAT-) (|PolynomialFactorizationExplicit&| . PFECAT-) (|PolynomialSetCategory&| . PSETCAT-) (|PowerSeriesCategory&| . PSCAT-) (|QuaternionCategory&| . QUATCAT-) (|QuotientFieldCategory&| . QFCAT-) (|RadicalCategory&| . RADCAT-) (|RealClosedField&| . RCFIELD-) (|RealNumberSystem&| . RNS-) (|RealRootCharacterizationCategory&| . RRCC-) (|RectangularMatrixCategory&| . RMATCAT-) (|RecursiveAggregate&| . RCAGG-) (|RecursivePolynomialCategory&| . RPOLCAT-) (|RegularTriangularSetCategory&| . RSETCAT-) (|RetractableTo&| . RETRACT-) (|Ring&| . RING-) (|SemiGroup&| . SGROUP-) (|SetAggregate&| . SETAGG-) (|SetCategory&| . SETCAT-) (|SquareMatrixCategory&| . SMATCAT-) (|StreamAggregate&| . STAGG-) (|StringAggregate&| . SRAGG-) (|TableAggregate&| . TBAGG-) (|TranscendentalFunctionCategory&| . TRANFUN-) (|TriangularSetCategory&| . TSETCAT-) (|TrigonometricFunctionCategory&| . TRIGCAT-) (|TwoDimensionalArrayCategory&| . ARR2CAT-) (|UnaryRecursiveAggregate&| . URAGG-) (|UniqueFactorizationDomain&| . UFD-) (|UnivariateLaurentSeriesConstructorCategory&| . ULSCCAT-) (|UnivariatePolynomialCategory&| . UPOLYC-) (|UnivariatePowerSeriesCategory&| . UPSCAT-) (|UnivariatePuiseuxSeriesConstructorCategory&| . UPXSCCA-) (|UnivariateSkewPolynomialCategory&| . OREPCAT-) (|UnivariateTaylorSeriesCategory&| . UTSCAT-) (|VectorCategory&| . VECTCAT-) (|VectorSpace&| . VSPACE-)))
 --E 155
 
 --S 156 of 237
diff --git a/src/input/unittest3.input.pamphlet b/src/input/unittest3.input.pamphlet
index 22e0c14..bd6c15c 100644
--- a/src/input/unittest3.input.pamphlet
+++ b/src/input/unittest3.input.pamphlet
@@ -17,76 +17,76 @@ Unit test the user level commands
 )set mes auto off
 )clear all
 
---S 1 of 19
+--S 1 of 75
 )lisp (identity |$inputPromptType|)
 --R 
 --RValue = |step|
 --E 1
 
---S 2 of 19
+--S 2 of 75
 )lisp (setq |$inputPromptType| '|none|)
 --R 
 --RValue = |none|
 --E 2
 
---S 3 of 19
+--S 3 of 75
 1
 --R   (1)  1
 --R                                                        Type: PositiveInteger
 --E 3
 
---S 4 of 19
+--S 4 of 75
 )lisp (setq |$inputPromptType| '|plain|)
 --RValue = |plain|
 --E 4
 
---S 5 of 19
+--S 5 of 75
 2
 --R
 --R   (2)  2
 --R                                                        Type: PositiveInteger
 --E 5
 
---S 6 of 19
+--S 6 of 75
 )lisp (setq |$inputPromptType| '|step|)
 --R 
 --RValue = |step|
 --E 6
 
---S 7 of 19
+--S 7 of 75
 2
 --R
 --R   (3)  2
 --R                                                        Type: PositiveInteger
 --E 7
 
---S 8 of 19
+--S 8 of 75
 )lisp (setq |$inputPromptType| '|frame|)
 --R 
 --RValue = |frame|
 --E 8
 
---S 9 of 19
+--S 9 of 75
 2
 --R
 --R   (4)  2
 --R                                                        Type: PositiveInteger
 --E 9
 
---S 10 of 19
+--S 10 of 75
 )lisp (setq |$inputPromptType| t)
 --R 
 --RValue = T
 --E 10
 
---S 11 of 19
+--S 11 of 75
 2
 --R
 --R   (5)  2
 --R                                                        Type: PositiveInteger
 --E 11
 
---S 12 of 19
+--S 12 of 75
 )set debug
 --R                    Current Values of  debug  Variables                    
 --R
@@ -97,7 +97,7 @@ Unit test the user level commands
 --R
 --E 12
 
---S 13 of 19
+--S 13 of 75
 )set debug lambdatype 
 --R-------------------------- The lambdatype Option --------------------------
 --R
@@ -112,11 +112,11 @@ Unit test the user level commands
 --R
 --E 13
 
---S 14 of 19
+--S 14 of 75
 )set debug lambdatype on
 --E 14
 
---S 15 of 19
+--S 15 of 75
 )set debug lambdatype
 --R-------------------------- The lambdatype Option --------------------------
 --R
@@ -131,7 +131,7 @@ Unit test the user level commands
 --R
 --E 15
 
---S 16 of 19
+--S 16 of 75
 )set debug dalymode
 --R--------------------------- The dalymode Option ---------------------------
 --R
@@ -146,11 +146,11 @@ Unit test the user level commands
 --R
 --E 16
 
---S 17 of 19
+--S 17 of 75
 )set debug dalymode on
 --E 17
 
---S 18 of 19
+--S 18 of 75
 )set debug dalymode
 --R--------------------------- The dalymode Option ---------------------------
 --R
@@ -165,7 +165,7 @@ Unit test the user level commands
 --R
 --E 18
 
---S 19 of 19
+--S 19 of 75
 )set debug
 --R                    Current Values of  debug  Variables                    
 --R
@@ -176,6 +176,343 @@ Unit test the user level commands
 --R
 --E 19
 
+--S 20 of 75
+)lisp |$frameAlist|
+--R 
+--RValue = NIL
+--E 20
+
+--S 21 of 75
+)lisp |$frameNumber|
+--R 
+--RValue = 0
+--E 21
+
+--S 22 of 75
+)lisp |$currentFrameNum|
+--R 
+--RValue = 0
+--E 22
+
+--S 23 of 75
+)lisp |$EndServerSession|
+--R 
+--RValue = NIL
+--E 23
+
+--S 24 of 75
+)lisp |$NeedToSignalSessionManager|
+--R 
+--RValue = T
+--E 24
+
+--S 25 of 75
+)lisp |$sockBufferLength|
+--R 
+--RValue = 9217
+--E 25
+
+--S 26 of 75
+)lisp SessionManager
+--R 
+--RValue = 1
+--E 26
+
+--S 27 of 75
+)lisp |$SessionManager|
+--R 
+--RValue = 1
+--E 27
+
+--S 28 of 75
+)lisp ViewportServer
+--R 
+--RValue = 2
+--E 28
+
+--S 29 of 75
+)lisp |$ViewportServer|
+--R 
+--RValue = 2
+--E 29
+
+--S 30 of 75
+)lisp MenuServer
+--R 
+--RValue = 3
+--E 30
+
+--S 31 of 75
+)lisp |$MenuServer|
+--R 
+--RValue = 3
+--E 31
+
+--S 32 of 75
+)lisp SessionIO
+--R 
+--RValue = 4
+--E 32
+
+--S 33 of 75
+)lisp |$SessionIO|
+--R 
+--RValue = 4
+--E 33
+
+--S 34 of 75
+)lisp MessageServer
+--R 
+--RValue = 5
+--E 34
+
+--S 35 of 75
+)lisp |$MessageServer|
+--R 
+--RValue = 5
+--E 35
+
+--S 36 of 75
+)lisp InterpWindow
+--R 
+--RValue = 6
+--E 36
+
+--S 37 of 75
+)lisp |$InterpWindow|
+--R 
+--RValue = 6
+--E 37
+
+--S 38 of 75
+)lisp KillSpad
+--R 
+--RValue = 7
+--E 38
+
+--S 39 of 75
+)lisp |$KillSpad|
+--R 
+--RValue = 7
+--E 39
+
+--S 40 of 75
+)lisp DebugWindow
+--R 
+--RValue = 8
+--E 40
+
+--S 41 of 75
+)lisp |$DebugWindow|
+--R 
+--RValue = 8
+--E 41
+
+--S 42 of 75
+)lisp NAGLinkServer
+--R 
+--RValue = 8
+--E 42
+
+--S 43 of 75
+)lisp |$NAGLinkServer|
+--R 
+--RValue = 8
+--E 43
+
+--S 44 of 75
+)lisp Forker
+--R 
+--RValue = 9
+--E 44
+
+--S 45 of 75
+)lisp |$Forker|
+--R 
+--RValue = 9
+--E 45
+
+--S 46 of 75
+)lisp CreateFrame
+--R 
+--RValue = 1
+--E 46
+
+--S 47 of 75
+)lisp |$CreateFrame|
+--R 
+--RValue = 1
+--E 47
+
+--S 48 of 75
+)lisp SwitchFrames
+--R 
+--RValue = 2
+--E 48
+
+--S 49 of 75
+)lisp |$SwitchFrames|
+--R 
+--RValue = 2
+--E 49
+
+--S 50 of 75
+)lisp EndOfOutput
+--R 
+--RValue = 3
+--E 50
+
+--S 51 of 75
+)lisp |$EndOfOutput|
+--R 
+--RValue = 3
+--E 51
+
+--S 52 of 75
+)lisp CallInterp
+--R 
+--RValue = 4
+--E 52
+
+--S 53 of 75
+)lisp |$CallInterp|
+--R 
+--RValue = 4
+--E 53
+
+--S 54 of 75
+)lisp EndSession
+--R 
+--RValue = 5
+--E 54
+
+--S 55 of 75
+)lisp |$EndSession|
+--R 
+--RValue = 5
+--E 55
+
+--S 56 of 75
+)lisp LispCommand
+--R 
+--RValue = 6
+--E 56
+
+--S 57 of 75
+)lisp |$LispCommand|
+--R 
+--RValue = 6
+--E 57
+
+--S 58 of 75
+)lisp SpadCommand
+--R 
+--RValue = 7
+--E 58
+
+--S 59 of 75
+)lisp |$SpadCommand|
+--R 
+--RValue = 7
+--E 59
+
+--S 60 of 75
+)lisp SendXEventToHyperTeX
+--R 
+--RValue = 8
+--E 60
+
+--S 61 of 75
+)lisp |$SendXEventToHyperTeX|
+--R 
+--RValue = 8
+--E 61
+
+--S 62 of 75
+)lisp QuietSpadCommand
+--R 
+--RValue = 9
+--E 62
+
+--S 63 of 75
+)lisp |$QuietSpadCommand|
+--R 
+--RValue = 9
+--E 63
+
+--S 64 of 75
+)lisp CloseClient
+--R 
+--RValue = 10
+--E 64
+
+--S 65 of 75
+)lisp |$CloseClient|
+--R 
+--RValue = 10
+--E 65
+
+--S 66 of 75
+)lisp QueryClients
+--R 
+--RValue = 11
+--E 66
+
+--S 67 of 75
+)lisp |$QueryClients|
+--R 
+--RValue = 11
+--E 67
+
+--S 68 of 75
+)lisp QuerySpad
+--R 
+--RValue = 12
+--E 68
+
+--S 69 of 75
+)lisp |$QuerySpad|
+--R 
+--RValue = 12
+--E 69
+
+--S 70 of 75
+)lisp NonSmanSession
+--R 
+--RValue = 13
+--E 70
+
+--S 71 of 75
+)lisp |$NonSmanSession|
+--R 
+--RValue = 13
+--E 71
+
+--S 72 of 75
+)lisp KillLispSystem
+--R 
+--RValue = 14
+--E 72
+
+--S 73 of 75
+)lisp |$KillLispSystem|
+--R 
+--RValue = 14
+--E 73
+
+--S 74 of 75
+)lisp CreateFrameAnswer
+--R 
+--RValue = 50
+--E 74
+
+--S 75 of 75
+)lisp |$CreateFrameAnswer|
+--R 
+--RValue = 50
+--E 75
+
+@
 )spool
 )lisp (bye)
  
